import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Соберите всю почту в этот ящик',
    from_='hello@yandex.ru',
    to=(),
    cc=(),
    bcc=(),
    reply_to=('foma@company.ru', 'petr@company.ru'),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='',
    html='<html><head><meta http-equiv="content-type" content="text/html; charset=utf-8"></head><body bgcolor="#ffffff" text="#000000"><meta http-equiv="Content-Type" content="text/html; charset=UTF-8">\n<title>Соберите письма из других почтовых ящиков в Яндекс.Почте</title><font color="#000000" face="Arial"> Здравствуйте!<br><br> Если у Вас уже есть почтовые ящики, куда приходят письма, Вам будет удобнее хранить и читать все письма в одном ящике.<br><br><table cellpadding="0" cellspacing="0"><tbody><tr><td valign="top">\n<a href="https://mail.yandex.ru/neo2/#setup/collectors"><img src="cid:collector.jpg@parts.yandex.ru" alt="Сборщик писем" width="135" border="0" height="100"></a>\n</td><td valign="top"> <font color="#000000" face="Arial"> В Яндекс.Почту можно скопировать всю переписку и адреса собеседников из ваших старых ящиков. С ящиками ничего не случится – они продолжат работать и принимать письма, а на новый адрес в Яндекс.Почте будут приходить копии этих писем.<br><br>Чтобы собрать всю почту и адреса в один ящик —\n<a href="https://mail.yandex.ru/neo2/#setup/collectors">\nнастройте сбор почты</a>. Для этого введите адрес ящика и пароль от него.<br><br>\n<a href="https://mail.yandex.ru/neo2/#setup/collectors">\n<font size="5">Настроить сбор почты</font></a></font></td></tr></tbody></table></font>\n</body></html>',
    headers={'content-type': ('multipart/related; boundary="===============1696383123=="',), 'mime-version': ('1.0',), 'reply-to': ('=?UTF-8?B?0L/RgNC40LLQtdGC?= <foma@company.ru>,\r\n =?UTF-8?B?0L/QvtC60LA=?= <petr@company.ru>',), 'from': ('=?utf-8?b?0K/QvdC00LXQutGB?= <hello@yandex.ru>',), 'subject': ('=?utf-8?b?0KHQvtCx0LXRgNC40YLQtSDQstGB0Y4g0L/QvtGH0YLRgyDQsiDRjdGC0L4=?=\r\n =?utf-8?b?0YIg0Y/RidC40Lo=?=',), 'message-id': ('<20110815165837.A26162B2802A@yaback1.mail.yandex.net>',), 'the-check': ('1', '2')},
    attachments=[
        dict(
            filename='collector.jpg',
            content_id='collector.jpg@parts.yandex.ru',
            content_disposition='attachment',
            content_type='image/jpeg',
            payload=b'\xff\xd8\xff\xe0\x00\x10JFIF\x00\x01\x02\x00\x00d\x00d\x00\x00\xff\xec\x00\x11Ducky\x00\x01\x00\x04\x00\x00\x00F\x00\x00\xff\xee\x00\x0eAdobe\x00d\xc0\x00\x00\x00\x01\xff\xdb\x00\x84\x00\x04\x03\x03\x03\x03\x03\x04\x03\x03\x04\x06\x04\x03\x04\x06\x07\x05\x04\x04\x05\x07\x08\x06\x06\x07\x06\x06\x08\n\x08\t\t\t\t\x08\n\n\x0c\x0c\x0c\x0c\x0c\n\x0c\x0c\r\r\x0c\x0c\x11\x11\x11\x11\x11\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x01\x04\x05\x05\x08\x07\x08\x0f\n\n\x0f\x14\x0e\x0e\x0e\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\x14\xff\xc0\x00\x11\x08\x00d\x00\x87\x03\x01\x11\x00\x02\x11\x01\x03\x11\x01\xff\xc4\x00\xba\x00\x00\x01\x04\x03\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x04\x05\x06\x01\x02\x08\x07\t\x01\x00\x01\x05\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x02\x03\x04\x05\x06\x07\x10\x00\x01\x03\x03\x02\x02\x05\t\x01\n\x0b\t\x00\x00\x00\x00\x01\x02\x03\x04\x00\x11\x05\x12\x06!1AQ"\x13\x07aq\x81\x91\xa12\x14\x15\x08\xb1\xd1Bbr\x92\xa2#3s\xd3\xc1\xe1\x82\xb2\xc2CSc\xb3\xc3\x16R\xd2\x83\x93$D%E\x18\x11\x00\x02\x01\x02\x01\x08\x06\x06\n\x02\x03\x01\x00\x00\x00\x00\x00\x01\x02\x11\x03\x04!1AQ\x91\x12R\x05aq\x81\xa1\xb12\xf0\xc1\xd1"\x13\x15\xe1Bbr\x82\xb2\xc23\x06\x16#$\xa2s4\x14\xff\xda\x00\x0c\x03\x01\x00\x02\x11\x03\x11\x00?\x00\xef\xea\x00(\x00\xa0\r\x1cy\xa6\x8biuiB\x9dV\x86\xc2\x88\x1a\x95bl:\xcd\x81\xa5\xa0\xa97\x98\xde\x90@\xa0\r\\Z\x1aB\x9cp\x84\xb6\x80T\xa5\x1e@\x0e$\xd2\xa4\xdb\xa2\x11\xba*\xb3)RV\x90\xa4\x9b\xa5B\xe0\x8eD\x1aF\xa8*fh\x00\xa0\x04b\xca\x8f5\x84I\x8a\xe0u\x85\xdfC\x89\xe4lH>\xa2)\x13O0\xe9A\xc5\xd1\xaa1jQ\xa1@\x05\x00\x14\x00P\x01@\x05\x00\x14\x00P\x04V\xe2%\xbcp\x94\x13\x7f\x84~<\x85\x1e\xa6\xday\x05\xc5z\x11\xa8\xd3\xe1\x9c\x9e\xcf\x9a\x9a\xd3]\xc4\xad0\x80(\x01\xbc\xe4\x07aIm^\xea\xdaZM\xb9\xd8\xa4\x8a\x92\xdb\xa4\x93\xe9\x19qV-t\x1ac\x15\xab\x1b\rW\xb9,6o\xe7H\xa7^T\x9c\xba\xd8\xdb.\xb0\x8fR\x1d\xd4$\xa6\t\xb0\'\xab\x8f\n\x00\x8f\xc1B\xf9v\x1e\x1424\xad\xb6\x93\xacZ\xdd\xb5v\x95\xc3\xceM2\n\x89"{\xf3\xdf\xb8\xe5\xd2H\xd3\xc8\x02\x80\n\x00\x87\xce\xe7Q\x89T(l\xa0=\x95\xc9\xbc#\xc1\x8f\xd6x\x15\xb8\xabq\xd0\xda{J\xb7E2R\xa7[,Y\xb3\xbfV\xfc\xb1U~\x9d$\xc5<\xae\x14\x00P\x01@\x05\x00#.:e\xc5~*\xfd\xc7\xdbSJ\xbf\x11e\x82\x0f\xdbJ\x9d\x18\xe8\xca\x8d0\x8c\xa3\xdd\x84-IS\xe8\x03\xbe\xd2og\x08\xd4G\x93\x9d#\x11\xb5\\\x82\xa1@\xf27\xb5\x02\x1a\xb8\x9dhR/m@\x8b\xf9\xc5\xa9S\xa3\x11\xaa\xa1\x9e\x19D\xe2\xe1j\x1aO\xc3\xb5py\x83\xa7\xf8\xaak\xff\x00\xb9.\xb6Eg\xc9\x1e\xa4>J\x92\xb4\xa5hPR\x14\x01J\x81\xb8 \xf2 \xd4\x04\xc6h\x027!\x9b\x81\x8fBT\xb7C\x8b2\x11\x0c4\xd1\nY}\xc1\xa8#\x98\xb1\t:\xcd\xfa)R\xadi\xa0M\xe4Be\xfcE\xdb\xb8_\x8a2\xd6\xe2\xbe\x11hC\xa1\xa0\x16\xad+\x17\xd7k\xdfM\xfb>zktM\xe8\x89f6%(\xefh\xf6\x13\x839\x88\x0f\xe3\xa3.k(\x97\x96B\x9c\xc6\xc6R\xd2\x1d}\x08Gx\xa2\x84\xde\xea\tO\x15[\x95&\xf2\xdaD\xa1&\x9bK"\xce=\xefS\xdfw\x1cu\xe9\xd7\xe4\xb5\xedN\x18y\xa7\x87\xb9\x07w\xa6\xea\xdc\x1b\xd5\xd2\xbf\x96\xc3Y\xc4aR\x7fW\xdd\xa0\x85:\xb1\xc4\xf16O\xac\xfa*Z{\xf2r\xecF\xde:\x1f\xfc\xf6akK\xf7\xa5\xea=8\x13s\xd4*\xd9\x88f\x80!wz3k\xdb\x19_\xf4\xd4\x9f\x85\xcf":\xdd\xc7\xbcP\x97\x07~\xd0\xd6\x94\x94\xa8(\x10\xbd:\x0f\x0e\x9a\x8e\xe6\xf6\xeb\xdd\xceZ\xc2\xbbj\xec~"\xack\x97\xa8\xe3\x98\xdfW\xbb\xe6NS\x0e$3\x11\x88\xcc\xba\x88Y\x946\xd9\xd0\xea%8\x96\x83\xe0(\xa8\xa1m\x93~\n\xd2zEd\xc3\x1b7(\xd71\xd9_\xe4xxZ\x9b\x8dj\xb3t{Q\xe9\xdbk\xc4\xad\xdb\x1f%\xb80\xb2\xa78\xe9aa\xe8j\x7f\xf4\x8bB$%F\xc0\xaa\xe6\xc1hU\xbc\xf5\xabg\xcd4\xf4:\xf63\xcfp\xca\xae\xe2\x7fU\xa6\xba\x99+\x8c\xf1Wr\xc8rlW\x14\x15(b\x1c1\xdf\xe0\x00\x96\xdfx\x03\x85\x16)\xd5q\xd5\xc6\x96M\xa6\xfa\x8b\x96\xd2mW5QOk\xc5\xfd\xc3\x07\x1a\xeey\xe5\xad\xd7\x8c\\n]\xf5\x83`\xa2\x85\x14>\x9b\x1e\x82\x94\x94\x9f=.=|+\xb77s-\xd6\xbbL\x1f\x8b%\tKJ\xdd\xf1\xa3\xf0%7&\xf4\xccG\xcbl\xfc\x8e6S\xec\xc7\xc9Ka\xe2\xd0Q\xba\xd9\x92\xd3\xc9\x01V\xe7\xd9#\x85GZ\xc6\x0f\xa7\xdau\x16\x12q\x9eO\xa8\xfcQ=\xb5<S\xc9\xc5\x89!\xb9c\xe2\x94\xdc\xf7T5(\x85)\x0bzBJ|\x80\x06\xc5\xbc\xb5w\x10\xa9%MQ\xf01\xad\xb7O\xc4\xfcY\x19\x1b\xc4\xcd\xcd\x9a\xc3\xee\x07e\xbe\x96\xa1\x98\x12KL4\x84\xa5(Iiv\x00\x81~\xcd\xb9\xde\xb3\xed]w,\xcao>R~O\'{vR\xe3K\xb3x\xa9m}\xf1\xb8\xb1R\xa4dQ9\xd7\\\x8f(\xc2i.\xa8\xa9\xa1\x1e\x14&\xd3\xdd\xe9\xbd\xb4\x82\x9e]|j|\x14w\xee4\xf3o%\xdc\x8dnn\xd4-\xdbk?\xc3r}nR~\xc2\xdf\x91\xf1\'s\xb1\x92\xc7\xb2\xcc\xa0&\xe5#\x85Kx$]\x01\x94\x85\x90\x81\xc8\\\xac\x03aL\xc5\xc9\xc5%\x1d2*\xc2)\xc5WSc=\xb3&fGs\xc3rK\xcbt\x06\xa7\xe5\x1c%D\xdd\xe7\xddRB\xfa\xb5Y\x00y\xabR\xcf\xbb\x85\xb8\xf8\xa7\x15\xe2\xcc\x14\xab\x88\x87B\x9c\xbc\x11\x13>k\xf2\xb1;\xb9\xd7\x15uK\xc8\xb7\x05\xa5~\x0cf\x9bM\xaf\xe4R\xcdd\xdf\xfd\xb9\xf4\xe4\xf5\x1d-\xbc\xcb\xa2>,n\xac\xd4\xbcw\xcb\xf7c/(\xe6\xb1\x902\xcc\xc0\x92\xa5\x15\x16\xa1kDV\x1aJI\xb0\x1a\x92T:kNxx\xbcM\xabif\x8cS\xed\xa5L\xeb8\x99\xc7\x05zM\xe4r\xc9\xd9_ar\xcfo\xdd\xd8\xcch\x10Q84\xf3\xf8U"{\x9aR\xa5)\xe7Kl6\xe6\xa2.\x15\xa8\xad\\*\x966I\\\x92\x86l\xb4\xdbD3\r)F\xe47\xb2\xd25\x97Nb\x9b\xf4\xdb\xe2~\xe7\x91+#\x83t7+h\xc0t\xc5\xc60\xd3Hm\xe2\xe3\xaf9\xa5z\xc5\xae\xa7\t\xd4\xadF\xddUK\x04\xdc\x9c\xa2\xbc\xb1:\xfeob2P\x9b\xc9r\xe5[\xd4\x92H\xebT\x8b\x0bzO\x9c\xd5\xf3\x93\x0e\x9a\x00\xcd\x00|\xc0\xf1\xb3j/hx\xb7\xb9\xf6\xebh\rE\x9a\xb7\xdc\x80\x10,\x90\x99\t\xf8\x96\x02\x7f\x16\xe1>\x8a\xe6\xef\xc7rO\xa1\x9e\xa1\x81\xbd\xf1\xad\xc5\xf1\xc2\x9f\x89d\xf1G\xb9\xed\xac\xb229\x9c\x0ey?\xaa\xdc8\x86]_\xedP\x1bp\x8fF\xa7+r\xd3\xad\xc4\xf8\xa3\xe0y\x8c\xa1\xf0\xf1\x92\x87\x14d\xb62\xc9\x8fe\xb6\xf7T8\xeb\xf7\x1f\x12\xa3(z\x96?\x9cjI\xf9\x97j\x1d\x17\x93a@\xc9\xb5m\x99%\xabv\x86\x0etey\x15\x12J\xd3\xec\xa7s\x1c\xb2o]\xb8>\xe3\x12\xea\xa3\xba\xba_\xe7~\xd2\xe3?\xf4\x91\xbc1Z\xad\xdb8\xbbz\x19Q\xa8c\xe4\x87\xa6\xb3\xa7\xb1\xe5\x9f\xdc~1\x17\x8e\x96\xbe]9\xc2;_\x1a\xfa\x90G\x03`f\xab\xed5{\x14\xfd\xe5\xd5\x1f\xcabA\xd2+\xefK\xd65\xc3\xe8F\xd6\xcf\x84\xf0\xd3\x8fu\xb1\xe7]\xd1\xfd*\xc8\xc2\x7f\xe5\xeb\xaf\x89?\xf1\xff\x00\xdb\x83\xfbU\xf1er1\xbe=\xf7\x12x\xbb\',\xeaI\xe4u\xbe\x18Mi\xf2\xcf=~\xd4\x9e\xca\x9a|\xf9\xe4Q\xd5n\xda\xda\x97\xb4\x9c\xcb-\t\xdd\xa8O\xf5x\xf8\x04\x8e\xae\xd2\xd2?\xcb\xaa\x98\x8c\xb3\xb6\xbbFV\x91}\x08\xb7\xec\xd8\xe5\x9c\x9eE\xd5\x02\x0c\x1cdX\xda\xbf\r\xc4\x05\x91\xe7\xed\xd6\xbf\x97\x07mqJOfC\x9f\xc3\xaa\xdeo\x86\x11[[eD\xbdm\xb3\r\xf5\x1e\xcc\xdc\x94\xd9\xeb\xf2\xa4Iq@\xfeKB\xb3\x1cw\xf7c\xc54tS\x96\xe4&\xf5%\xdc\x86\xf9\x08\xcbS8\x9cA\x1d\xb7\xbeY\x05I\x1cx\x00f=\xedX\xbdm\xd8\x92x\xcb\x974A>\xe5\x90\xc6\xbb\x1a`\xad[\xe3\x97\x8b^\xc6#\xe2\xa6k\xe5x\xed\xc5\x92B\xac\xb6B`\xc4\xfcf\x1b\x08H\x1f\xf1d~msw\xe7L\xbe\x99>\x96kr\xfb_\x1b\x11Mm/[-_J\xbbHC\xc2\xc2\x94\xe2=\xedy\x07n.9w,\x03\xe5\xe0\xa5\x8f5I\x81\x86\xe5\x8a\xe9\x91\xbb\xce\xefV\xf4\x92\xfa\xb4\x82\xec\xcb.\xfc\x87Q_\x8d\xaa\xd1\xcb\x99\xa0\x02\x808\xb7\xeb\x87m*\x16Wlo\xd8\xe9\xe0Ra\xc9 }\xf4e\xf7\x88$\xfe\x12\\P\xfeMd\xe3a\xef\'\xadP\xec\xf9\x15\xff\x00\xf15\xa6\x12R\xecy\xfc;\xca\xdf\x86\xd3[^\xd3\xdb\xee\x95]X\x1c\xb3\xf8\xe5\x9e\xa8\xf2\x16T\xd7\xa3D\x84\xfa\xa9\xf8i\xd6\x10\x96\xa7M\xb9\x0c.\x7fk\xe0c\xa3%\x9byl\x96C\xd5e\xa1,n\x1c,\x9bX*j\x02\xad\xd0^mI\xfbmZ\x17U)\xd0\xcc\xe6\xa8\xda\xeb*y\xd8\x89g\x1f\x98\x86mf\xce\xe0\x8d\xa7\xc8\xbf\xd3\x0f\xe7R\xe3\xb2\xc6\x0f]\xaf\xcb#\x17\x11\xfb\x97:\x9f\xe9d\xd3\xba\x1ec\xc2\x80y9\xf2\xcfdu\x13PG\xc9\x0fM\x0c\xe9ly\'\xf7?TE\x94\xda[\xc2Np\x1fzT\xb0\x0f\x99\x12\x7f\xde\xab\x98\xc7\x97\xb1~S\x05\xba[\xafL\xbfP\x9e1\xb4\xb7\xb4r\xca\xb0\xed";7?\xdeJl\x1a\xcc\xc2\xff\x00\xe5\x8f\xa6\x92\xe7#\xc9b\x1f\x89\xff\x00\xc6Eg\x08\xdf\x7f\x8f\xc54\xaerR\xd2\xadn\x07\xe2\xe7\x97=\xa0V\x8f.\xc9\n\xfd\x99\xbd\xb5\xf6\x9a<\xf7.&Q\xd5(Gb^\xc2FY\x12w6p\xa7\x8a\xbb\xb8\xf1\x91\xe7^\xb2G\xadb\xa9\xdf\xfd\xe5\xd1\x16W\xc4:Z\x97\xa6\x83\xd0\xe0:\x98XM\xd3\x96 \x04\xae[\xe9J\x8fJ"$ \x7f\x86kc\x13\xee\xc2\xd4uB\xbb[ff\x125\x9c\xde\xb9SbH\xa0\xe4c)\x18\x1d\xb9\x8aM\xfb\xd3\x01\x94*\xdf\xdaJJ\x12}\xaf\x1a\xaf\x85U\xbfo\xec\xefKb/\xe3\xa5\xfe\xbc\xfe\xd3\xa6\xd7BN9nV\xf8\x88\xb5\x80#A\x13\xb2Nu\x046\xae\xe1\xbf\xcdl\xd5\x8c;\xdd\xb1v|M.\xfa\xbf\x02\x0c_\xefZ\x86\x88F\xbd\xdfI\xe5^*\xbf#(\xde\xdc\xdbm\\\xcc\xcdJ\x13\x1fG3w\x16]\x00\xff\x00)\xe6\xff\x00&\xb9\xacKmn\xe9\x95\x16\xdc\xac\xe9\xff\x00\x8e\xc1F\xb7\xa5\x9a\x11r;/\xc2\xcc\x0bX=\xb2\xd2\x1bH\tXKM~\xc62{\xa4\xfa\xc8R\xbd5\xb4\xd6\xeaQZ\x11\x91\x8a\xb8\xe5,\xb9\xf3\xbe\xb7\x95\x97q\xd7\xd7\xe9\xa6\x94\xcc\xd0\x01@\x1eA\xf55\xb4\x93\xbb\xbc\x1e\xce\xb2\x96\xcb\x92\xb1iNN8\x02\xe4\x18\xf7\x0e\x1fCj]T\xc5\xc6\xb6\xeb\xab)\xb5\xc9\xee\xeeb\x14^i\xa7\x1d\xb9\xbb\xe8q\x8f\x84\x19\x17d\xe07\x06/W\xe9\x8cX\xd9\x06\x87O}\rJ\x8e\xe1\xf3\xf6Z\xaa\x18\x7f,\xe3\xdb\xeb-\xff\x00\'\xb6\xe7f\x174\xd2\x9d\xb1=\xc7-\x94\x0fc\xe0\xe4\x9bW\xb8\xe49@\xf9\x03\x88Q\xf6V\xc5\xdc\xb1o\xb4\xc1r\xde\x92|I=\xa8a\xbb\xa4\x04\xe4\xf3\xed\x13`\xa9rT<\xd2\xe1\x03\xf6\x8a~+-\xabo\xa2\xe2\xf5\x98\x98\x85\xfeW\xd3\x1f\xd1\xf4\x0e>1)\x8b\xe1"uX\x8f\x81?\x93\x19uR\x1eHzhgE\x87\xfd\xa9\xfd\xcf\xd5\x11\xcc\x99\xa1\xad\xb8\xf9*\xb9[\xd2\xb4\xfe1\xd4?\xa5Vq\xcf?\xdd\xfd&\r\xdc\x96\x9f\xe3\xf5\x98n[L\xec,\x9b\xcbW\xfd\xccP\x90O\xdf!e\xc3\xecER\xb3\x93\r\x03W\x92C\xfcV\xd6\xb4\xfb\xf2z\xc8}\xbc\xf2\x03\xd86\n\xac\x19j\x00P\xe9\xbbq\xdcx\xfbMh\xe0\xd5,\xfe\x15\xde\xd1/4\x96\xfe2]7%\xddQ\xde\xdf\x90\xdc\xac\xfc\x97Tn\xdb\xf9v\x9b\xe3\xc0\x94\xc7Kd\x8f\xcc5B\xe6[\xd3\xeaK\xbc\x8f\x15\xe5\xa6\xb9z\xcb^K"\x88\xfe\x16\xca:\xec\xf4\xd4:\xe7\x0ez\xe6\x15\x91\x7f?z+_\x1c\xff\x00\xca\xd7\nKbE>^\xbd\xd8\xbdm\xcb\xbd\xb2\'\'!\xaf\xf5<&u\x0e\xe6\x1fv\xabt\x04DB\xdc\xff\x00)5\x1d\x8c\x92\x9c\xb8m\xfefO\x8a[\xca\xd48\xa4\xbd\xa3\\b\x82\xd9\xdc\x92\xb5v\xfb\x88xVW\xf8o\xd8\xb9\xeduT\xfb\xbe\xe6\x16\x11\xe2m\xfa\x8a\xb7\xde\xfd\xfb\xb2]\x10E?\x03\x10\xee\xff\x00\x1b\xee\xc2{\xc8\xb8&P\xdct\x9fw\xbeY\x01\xb1\xebZ=U\x87f?\x13\x10\xb5EW\xd3\xb0\xed\xac\xa5g\x01\xff\x00d\xa9\xf8c\x95\xf8\x1d\xcb\x12* \xc1b\x1b_\xab\x8e\xd2ZO\x99\t\x02\xfe\xca\xd3n\xae\xa7))oI\xbdb\xe9\xbd\xbb\\\xeeyu_\x87\xb2\x90h\x1a\x00\xcd\x003\xcb"#\x98\xb9\xcd\xcfo\xbe\x82\xb8\xee\xa6K?\xed\xb4Pu\xa7\xa3\x98\xb8\xa4\x96l\xa3\xed\xb6\xa4\x9a\xcfS\xe7&\xd9\xd9\x19-\xaf\x9e\x91\x92\x8d\x94\x8c\xbck\xff\x00\x14\x84\xc7(s\xbc\x0cK\t!$\xf2\xbaV\x84\xab\xd7\\\xa5\xaecn\xdc\xebG\x9a\x87w\x8d\xc3O\x13i\xdb\xc8\xbd\xea\xed\xce[\x16\xac\x81\xc2\xa7\x13\xf3\x06C\x89d\xb0\x9749k\x02J\r\xb9\xf0\x06\xd5ms\x9bJ\n;\xaf"\xa6\x83\n\x1c\x8e\xeca\x18\xef*\xc5SOa\xbeq\xe9\xb9\x89\xd3$\xb79\xb6\xcc\xc0\xce\xa4\xad\xb5\xf0[lwJ7\x1dg\x95:|\xee\xd4\xad\xc6;\xaf\xddm\xe8\xd2\xa8V\xbb\xfcv\xf4\xa7\xbd\xbd\x1c\xd4\xd3\xd3\xed\x12uy@v\x88\x13\x1b\xb6\xd9KI\x90\x9d\x0b\xfd)i\nn\xe8\xe3\xc2\xf7\xe9\xa8c\xce-(\xc5n\xbc\x9dF\x8c9E\xd8\xc1\xc7yeT\xd3\xad?P\xb2\xe6\xe4\x1d\xc77\x00\xbe\x9dM\xb8\xe3\x8bV\x85i!kI\xb0\xf4\x0bS\xb1\x1c\xea\xdd\xc4\xfd\xd7\x95SF\xaa\x19\xf7?\x8e\xdd\x9c\x1cT\xa3\x96\xba\xf4\x98\x97/!#k;\x80C\x9a_z@\x91\xdf\x94\x92\x8b\x04-\x16#\x9d\xfbU\x17\xcd\xed|%\n<\x8b\xa0\xd2\xc0rk\x98e\x04\xda{\xbdz\xd3\xf5\tCVV,\xe4J*\nm\xb3p\x94\xa4\xde\xc9\x8f\xdc\x0eg\xd3V\xad\xf3\xeb1\x8d7^\x8dZ\x08\xa5\xc9.\xca\xee\xfb\x92\xce\xde\x9d!\x88N_\x1e\xf2\x1e[\x89Z\xc2\xe6?p\x08\xbb\xb2\x90\xe2\x1b<O\xdek\xe3U\xe3\xce\xac\xa9\xb98\xbc\xad=\x82\\\xe4wf\x97\xbd\x1d:\xc9\xec\xd6O!\x93\xc2B\xc2\xc7\xb3H\x8c\xe4u8\xa5\x90u7\x1c\xb4H\x16<\xc8o\xa6\xa6\xb9\xcf\xedNN[\xb2\xca\xfa\x06Z\xe47m\xc5-\xe8\xe4T\xd3\xa8b\xb4\xe5\x9f\xc9\xbb8\xc8i!\xc6\x96\xd0I\n$\x17BR\xa3\xc3\xc9\xab\xd7G\xcf\xec\xa8\xcd(\xcb\xdf\xa6\xad\x04\xb3\xe4\x97%v\x13\xdeT\x82\xe9\x14m\xac\xebp\x8cF\xe53\xad\xd9\xce\xe4\x1fr\xcb\x01JRV\x1bH\x1f\x83\xa8z\xa9\xd7\xff\x00\x90Z\xb8\xa2\x94e\xee\xaah*\xc7\x90]_Z>m\xe7\x9c\x9a\xf0\x1b\x0e\xf6\xcf\xdej\x9f\xb8\xe4\xa2k\xd9\x89\xc9:\xe2\xa5CJ\xdd%\x0c\xa4\x85\x91\xc1+X&\xddT\xdc\x173\xb4\xe6\xe2\x93\xac\xcdLf\x1a\xe7\xc0J\xaa\x90\x8f\xd3&vq\xb5t\x07\x1c\x04\xf0\xe0/\xe4\xa0\x0cj7)\xd2x[\x8f\x0bq\xf4\xd0)\xb5\x02\r2\x8d\x97\xb1\x93Y\x06\xc5\xc6\x1d@\'\xa3R\x08\xa4y\x87A\xd2H\xe0%\xe5]\x00\r7\xd0\x02}B\xd5\xe6S\xf35\xd2z\xacs\t+.\xe7\xdfi@\xe9&\xdfv\xa2\xca;!\x81\x96"\xc0\xad>\xb1\xf6\xd1A2\x1b|\xdd)$w\x88\x1d<\xc5\x14b:\x08\xaf?\x1d\x0e%\x85Jm\x0e\xae\xeaCZ\x92\x14\xa0\x9ed\x03\xc4\xda\x8d\xc9g\xa0o,\xc6\x9f=\x8a\xea\xdce2\xd0\xa7[\xb7x\x84\xa8\x12\x82x\x8b\x8e\x8b\xd28Ih\x1c\xa5\x16g\xe6\xed&\xff\x00\xa5\x04\xf9TM&\xeb`\xda59\xb6\xff\x00\xb6O\x0e\x17\x17\xa4\xdc`\x9a7Ns\xa9w\xbf.\xc9\xfb\x94n\xb1E[\xcc\xbf~\xc9U\xc7+\nZ\x06A\xcbyyJ\xe0\n\xfc\xd4\xe4\x86:\x16\xbf\x0f\xe4I\x99\xbdv\xf3.)A*\xc8\xc4$\x9e]\x97R\xaf\xe0\xadN\\\xbf\xd8\x8fY\x9f\x8fiX\x9fS;g\x9d\xc7Mw\xe7\x9c\x00\x00r\x1dg\xd6o@\x19\xa0\x02\x80\x13\x90\xda\x9d\x8e\xebI\xf7\x96\x85$_\x95\xc8\xb5\x02\xac\xe7\xcew#-\xbe\xc2\xcd\xd6\x07hp\x1ck\xcc\xafd\x9b\xebg\xa8\xc3,P\xcd\xd8\xee{\xc9A#\xa3\x95\xbe\xdab\x92$\xa0\xd1\xc6dp\xba~\xcf\xbbORA\xba$\x19wW\xba\x07\x94\xda\x9d\xbc\x86\xd0\xabnD>\xden\x1c\xd6\xd0\x14\xec\x18\xae\xcb\tO5!\xb7P\x1cH\xb0\xe9AU]\xb0\xd3\x83Z\xdd\n\xd7*\xa4\x9a\xd0\x86\x10\x9c\xc9c]\xc8\xccKZ\xe5\xc8^=\xd7\x91mJ\xff\x00\xabZ\xae\x808q\t!"\xa4\x9a\x8c\xe8\xb4-\xee\xe1\xb1\x94\xa3W\xd5\xdeH\xaf5\x98rS\x90\x98\x8a\xe3n*J\xdal|8u\xf44\xd3(p\x82\xde\xa0\n\x89W_*\x85Y\x86v\xf4k\xc9\x9fX\xf7zo6\xbd^\xa2{\x1a\xac\x94\x88,;:)\x8f,\x82\x1diCM\x94\t\x17\x02\xe6\xd7\x1cj\x9d\xc5\x18\xc9\xa4\xea\x8b\x10m\xc5U\x12H\x12\r\xbb \x0f)\xa8]5\x92\xe5\x1d\xa3\xe2Q\xc6\xc0\xf9\x01\xbdF\xdcGe\x17k\xe35\xdc%\x16\xeb&\x95J#Ze\xdf\xc2\xf4\xc8_\x88\x1bi$$\x7f\xe4c\x93et$\x95\x1f`\xad~V\xe2\xf1\x11\xa1\x95\xcc\x94\x96\x1eu\xd4w(\x1co]\xf1\xe7fh\x00\xe8\xa0\x02\x80\n\x00\xf9\xe18G\xef\xd4T\xe1+\xb9\xd4\x9b\xf4\x82k\xcb\xb1\x15\xf8\xb2\xebg\xac\xd9Kqu\x0cKm\xac( )`t\xa4^\xab\xd5\x92\xd1\t\xad\xa6\xc5\xae\xd2\x89\x1c=\xd3Bl\x1aF\x03\x08\xb8"17\xe5\xc0\xda\x96\xafX\xda#S\x8fes\x1b\x97\xf0ES\x1bmM!\xc1\xcc6\xb2\x14\xa1k\xdb\x89\x03\x9d9\\{\xb4\xaeA\xae\n\xb5\x13{\x17\x19\xf7\xddqX\xf2\xb7\x9eS+t\xdc\xdc\xaa)\xd4\xd1\xe0~\xf4\xff\x00\x1d9]\x92T\xaej\xf7\xe7\x11\xdb\x8b\xf4\xd4!3\x05\x1eJ\x9d\xef\xe1\x90\xeb\xcf|J\xdcC\x85\x0b\x0f\x04\x84k\x0bJ\x81I\xd24\xf04\xb1\xbd(\xe6z)\x98\x1d\xb8\xbd\x02\xf1\xa1*+M\xc7\x8a\xc6\x96ZN\x94\x80\xbb\xd8yI\xb95\x1c\xa7\xbc\xea\xc9c\x14\x95\x12\x1c\x06\xde\xb5\x96\x9b[\x91\xbdF\xd8\xea!V\xd9_+\x12I\xe3{S[\x17 \xf5\xa6\x1c\x1f\xd5\x92\x0f\x98Sj#\x92.\xde\x16\xc7y>!m\x93\xdd\x10>=\xbb\x9b\x82x!d\xfd\x95\xb5\xc9\x9dqQ\xed\xf029\xac\xbf\xd6\x9fW\xac\xed\x8a\xf4S\xcd\x82\x80\n\x00(\x00\xa0\x0f\x02\x95\xf4\xcf\x1d\xd7\x96\xe3y\xd1\xa1JQJU\x11:\x85\xc9<Oxo\xea\x15\xce]\xe4\x91\x9c\x9c\xb7\x9eW\xa8\xe9\xa1\xcfe\x14\x96\xe2\xda ~\x99\xdd\xb1\x03>\x80\x0f!\xf0\xc4}\x8b\x15\x17\xc8!\xc6\xf6\x0e\xf9\xfc\xb8;\xc4\xbf\xf9\x99\xe1\xff\x00\xbai^x\xea\xfd\xe57\xe4\x11\xe3{\x07\xff\x00`\x97\x02\xda&\xaf\xa6\xc9\xe9\xf72\xac\x13\xfb\x03\xfc.R|\x82<O`\xef\xec\x12\xe1[Y\xa9\xfap\xca\x11\xa7\xe6m[\xa6\xed\x1b\x7f\x89K\xf2\x08\xf1=\x82|\xfe\\+i\xaa\xbe\x9c2\x9alrM\x10:;\xa5[\xd4\x17G\xc8#\xc4\xf6\t\xf3\xe9p\xad\xa6\x87\xe9\xb3&x\x8c\x93\x02\xff\x00\xdc\x92}\xaeQ\xf2\x18\xf11\x7f\xb0K\x85m\x0f\xfek\xcb\x1eyV\x7f\xe4\x9f\xdeQ\xf2\x08q0\xfe\xc1.\x15\xb4Q\xbf\xa6\xac\x80\x1cr\xac\xfaYW\xef)~A\x0e&5\xf3\xf9p\xa1\xc3\x7fM\xf3Rx\xe5\x98\x03\xf6\n\xfd\xe5\x1f!\x87\x13\xd8\'\xcf\xa5\xc29G\xd3\xac\xbb\xf6\xb2\xcc[\xaf\xb8_\xef(\xfe\xbf\x0e&7\xe7\xb2\xe1\xef,\x9bO\xc1D\xed\xcc\xee?8\xeeQ/.\x03\x8au,\xb6\xc9N\xa5)\xb57\xc5Ef\xc3\xb5\xd5W0\x9c\xa2\x18{\x8ajU\xa1S\x13\xcd\xa5z\xdb\x83\x8d*z\xddn\x98a@\x05\x00\x14\x00P\x06\x0fE\x00f\x80\x0e4\x00P\x01@\x05\x00\x14\x00P\x01@\x05\x00\x14\x00P\x01@\x05\x00\x14\x01\xff\xd9',
        ),
        ],
    from_values=EmailAddress(name='Яндекс', email='hello@yandex.ru'),
    to_values=(),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='привет', email='foma@company.ru'), EmailAddress(name='пока', email='petr@company.ru')),
)