import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='You may_be Eligible for Legitimate_Cash from_GovAgencies! ',
    from_='infoz@reactive-outpost.com',
    to=('someone@yahoo.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='\r\n       <HR>',
    text='',
    html='',
    headers={'x-ymail-umid': ('1_28022_AGnHtEQAAW9xTQLt8wZPlyfni5U',), 'x-apparently-to': ('someone@yahoo.com via 68.180.199.105; Fri, 10 Dec 2010 19:20:19 -0800',), 'received-spf': ('pass (mta1007.mail.sp2.yahoo.com: domain of return@reactive-outpost.com designates 74.206.28.55 as permitted sender)',), 'x-ymailisg': ('EfAmUiocZAp0Gt06jFhMyq.RIPUVX9lzgOtsRqYzqYiHPTr1\r\n 0fU8Vw4OuGrVz8pSoGW6xDId01O9G9v_HqarLXv8V_3Z9ut5fddpRwyrVOpc\r\n 1NYVLhP.FzTcsd9snLKon1z0xEKDX0aWVgu6rOeJ3niXPtE3ubgKne3SWhrc\r\n 9Jh34ln.bbeJ52jQ7ToV0m5oC1_T47MCsj._NgxOknVeA1lAJbbtNAEclmXl\r\n SQvHnQENVjs9FKYmFsB8d1dSX61CsJq0OMSpC5aqnGFAV2DBPOggUD217rpT\r\n n.5Pe5NXv16E0mXO2gNKgtho5W72qSE.1nWBGc5Vl0h8XrXUj._O9Nkajzg2\r\n .klfTThF3zT2ThdTWgFl4lwkNjPKrc1EvlDcd1IPDQYwvMc1SEUpP_lddKwd\r\n aQiDt9G9Bu_Nf9vS5T97ZrS6pJJde4U0vrV872UEF.Mj2kpocFr_ba3fC6wP\r\n kUO.gj3xw2YQmo3I56NV66VndTOrSya2qAGpkCjkWtT6irAxwXakWlts.EFC\r\n iCRmdqsx7CN4UdCJw3vtDc7ASdV5Ty.kKy2GvIrHOFW.gFYGCXM7V0YnXBD1\r\n ho5ePgvP6hGNkrHA9MQzUKq7s6uikRvVPBR7ojjcxqpKOgilKuobsYeuEKZ.\r\n kOvWe6P3uZJxV4KVnGfBxCe9SU27RdVpdlWmI3cJc7ut2OfMUoTnI_dVBbK8\r\n 1O0tXTco9FYvL8IJfS4RzSnQOw7HDcqF4oNAeghagmlKAuvSCYk19XkqIdDd\r\n tzQO1K3DxMIdvS5ut39WQ.LoDu0b6BmFB.YDgUMF6zM3PtgzoJuVumOg1fvh\r\n jGf.3v5mgno63PiAoKoBSQkdCdf0GD_jPX1RX_Us405EVLsTjzyjiEno99Vq\r\n pxps1ab0rNal.g4Nep2ik_W7TgX6GCxUtZVFoHRbl4rA7gMPIPuF0MF5SkTN\r\n jd6vOu6eYRCyCBo_afBI_FkaG6J4gxis8FtAOpUFmXLW7Iwh2uVr4aoiv7ag\r\n Ee2U3XYQovYoYtzCsg.iAe97SjJcqINnps0DoC5ky9ijX9WSz4tJj_HgXWAo\r\n 2e8gh.25kkMg70QTFOdPONgQe3dF2g9wI7ELcIcMYSyMbvqqAY3OMTigxh9O\r\n _7PpaK_qHQ270JbYhnK53ZrNrIIwM1lhBjdjLfNjSaotnLT5.t1BobGskqhz\r\n 90CGlOIrzeI2xo_3c8Q.K8hceK_9oxsMP7TyML6J9KaEbV3lW0vHFUxXb21u\r\n 4bdKY3KBsxOPCA--',), 'x-originating-ip': ('[74.206.28.55]',), 'authentication-results': ('mta1007.mail.sp2.yahoo.com  from=reactive-outpost.com; domainkeys=neutral (no sig);  from=reactive-outpost.com; dkim=neutral (no sig)',), 'received': ('from 127.0.0.1  (EHLO reactive-outpost.com) (74.206.28.55)\r\n  by mta1007.mail.sp2.yahoo.com with SMTP; Fri, 10 Dec 2010 19:20:19 -0800', 'from localhost (127.0.0.1) by reactive-outpost.com id h0calo0n7lgf for <someone@yahoo.com>; Fri, 10 Dec 2010 22:08:27 -0800 (envelope-from <return@reactive-outpost.com>)'), 'from': ('"Grants-Notification" <infoz@reactive-outpost.com>',), 'subject': ('You may_be Eligible for Legitimate_Cash from_GovAgencies! ',), 'to': ('someone@yahoo.com',), 'precedence': ('junk',), 'in-reply-to': ('someone@yahoo.com',), 'content-type': ('text/html   ; charest="us-ascii"',), 'content-transfer-encoding': ('7bit',), 'date': ('\r\n       <HR>',)},
    attachments=[],
    from_values=EmailAddress(name='Grants-Notification', email='infoz@reactive-outpost.com'),
    to_values=(EmailAddress(name='', email='someone@yahoo.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)