import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Fwd: Signed email causes file attachments',
    from_='xxxxxxxxx.xxxxxxx@gmail.com',
    to=('xxxxx@xxxxxxxxx.com',),
    cc=(),
    bcc=(),
    reply_to=('xxxxxxxxx.xxxxxxx@gmail.com',),
    date=datetime.datetime(2005, 5, 8, 14, 9, 11, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=68400))),
    date_str='Sun, 8 May 2005 14:09:11 -0500',
    text='We should not include these files or vcards as attachments.\r\n\r\n---------- Forwarded message ----------\r\nFrom: xxxxx xxxxxx <xxxxxxxx@xxx.com>\r\nDate: May 8, 2005 1:17 PM\r\nSubject: Signed email causes file attachments\r\nTo: xxxxxxx@xxxxxxxxxx.com\r\n\r\n\r\nHi,\r\n\r\nJust started to use my xxxxxxxx account (to set-up a GTD system,\r\nnatch) and noticed that when I send content via email the signature/\r\ncertificate from my email account gets added as a file (e.g.\r\n"smime.p7s").\r\n\r\nObviously I can uncheck the signature option in the Mail compose\r\nwindow but how often will I remember to do that?\r\n\r\nIs there any way these kind of files could be ignored, e.g. via some\r\nsort of exclusions list?\r\n',
    html='',
    headers={'return-path': ('<xxxxxxxxx.xxxxxxx@gmail.com>',), 'x-original-to': ('xxxxx@xxxxx.xxxxxxxxx.com',), 'delivered-to': ('xxxxx@xxxxx.xxxxxxxxx.com',), 'received': ('from localhost (localhost [127.0.0.1])\r\n\tby xxxxx.xxxxxxxxx.com (Postfix) with ESMTP id 06C9DA98D\r\n\tfor <xxxxx@xxxxx.xxxxxxxxx.com>; Sun,  8 May 2005 19:09:13 +0000 (GMT)', 'from xxxxx.xxxxxxxxx.com ([127.0.0.1])\r\n by localhost (xxxxx.xxxxxxxxx.com [127.0.0.1]) (amavisd-new, port 10024)\r\n with LMTP id 88783-08 for <xxxxx@xxxxx.xxxxxxxxx.com>;\r\n Sun,  8 May 2005 19:09:12 +0000 (GMT)', 'from xxxxxxx.xxxxxxxxx.com (xxxxxxx.xxxxxxxxx.com [69.36.39.150])\r\n\tby xxxxx.xxxxxxxxx.com (Postfix) with ESMTP id 10D8BA960\r\n\tfor <xxxxx@xxxxxxxxx.org>; Sun,  8 May 2005 19:09:12 +0000 (GMT)', 'from zproxy.gmail.com (zproxy.gmail.com [64.233.162.199])\r\n\tby xxxxxxx.xxxxxxxxx.com (Postfix) with ESMTP id 9EBC4148EAB\r\n\tfor <xxxxx@xxxxxxxxx.com>; Sun,  8 May 2005 14:09:11 -0500 (CDT)', 'by zproxy.gmail.com with SMTP id 13so1233405nzp\r\n        for <xxxxx@xxxxxxxxx.com>; Sun, 08 May 2005 12:09:11 -0700 (PDT)', 'by 10.36.10.16 with SMTP id 16mr1012493nzj;\r\n        Sun, 08 May 2005 12:09:11 -0700 (PDT)', 'by 10.36.5.10 with HTTP; Sun, 8 May 2005 12:09:11 -0700 (PDT)'), 'domainkey-signature': ('a=rsa-sha1; q=dns; c=nofws;\r\n        s=beta; d=gmail.com;\r\n        h=received:message-id:date:from:reply-to:to:subject:in-reply-to:mime-version:content-type:references;\r\n        b=cid1mzGEFa3gtRa06oSrrEYfKca2CTKu9sLMkWxjbvCsWMtp9RGEILjUz0L5RySdH5iO661LyNUoHRFQIa57bylAbXM3g2DTEIIKmuASDG3x3rIQ4sHAKpNxP7Pul+mgTaOKBv+spcH7af++QEJ36gHFXD2O/kx9RePs3JNf/K8=',), 'message-id': ('<e85734b90505081209eaaa17b@mail.gmail.com>',), 'date': ('Sun, 8 May 2005 14:09:11 -0500',), 'from': ('xxxxxxxxx xxxxxxx <xxxxxxxxx.xxxxxxx@gmail.com>',), 'reply-to': ('xxxxxxxxx xxxxxxx <xxxxxxxxx.xxxxxxx@gmail.com>',), 'to': ('xxxxx xxxx <xxxxx@xxxxxxxxx.com>',), 'subject': ('Fwd: Signed email causes file attachments',), 'in-reply-to': ('<F6E2D0B4-CC35-4A91-BA4C-C7C712B10C13@mac.com>',), 'mime-version': ('1.0',), 'content-type': ('multipart/mixed; \r\n\tboundary="----=_Part_5028_7368284.1115579351471"',), 'references': ('<F6E2D0B4-CC35-4A91-BA4C-C7C712B10C13@mac.com>',)},
    attachments=[
        dict(
            filename='smime.p7s',
            content_id='',
            content_disposition='attachment',
            content_type='application/pkcs7-signature',
            payload=b'0\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x02\xa0\x800\x80\x02\x01\x011\x0b0\t\x06\x05+\x0e\x03\x02\x1a\x05\x000\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x01\x00\x00\xa0\x82\x06\x140\x82\x02\xcd0\x82\x026\xa0\x03\x02\x01\x02\x02\x03\x0e\\\xf90\r\x06\t*\x86H\x86\xf7\r\x01\x01\x04\x05\x000b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA0\x1e\x17\r050329093910Z\x17\r060329093910Z0B1\x1f0\x1d\x06\x03U\x04\x03\x13\x16Thawte Freemail Member1\x1f0\x1d\x06\t*\x86H\x86\xf7\r\x01\t\x01\x16\x10smhaunch@mac.com0\x82\x01"0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x03\x82\x01\x0f\x000\x82\x01\n\x02\x82\x01\x01\x00\x9f\xdd\x1d>\xc6\x12\xdc\xb8\xdf1\x8d\xb5\xd4\xe4\x98\xac4\x0b\xcf\x03X>P\x0b\xef\xef\xf4\\\x0f\xa4w/?\xad\x19\xf2\x10qF\xc2\x13B\x0eh4\x07\xaaq\x0b\xbc\xf7\xc7\x12C\xff\xc1\x9f\t\xdf\x88aE\rQ\x05y\x9b\xd3$\xc5\xf3\xfd\xa55WeR\x18-\xa0p\xa3\xccR\xdc\r\x1a\xd4\xb5\xdejW&\x94F\xc9\x89\xb9\x8a\x90F\xa8]\xc8\xb72\x1a\xf2.\nZk\xe2\xa4\xfe\xc1\xf4\xd9#Z\xb43\xb5\xbd-\xbcl\xfb"m\x9a\\s\xa7^\x16\xb9Z\x85&\'/\xe3\xd6\xe7\x89\x83La\xc8p#v}\xbc\x7fc\xaa\xac\xa7:\xa6\xb4\xa6\x97\xae\xfe\xf94\x1bn\xcb\xd7\x01\xe8\xac\xd4\xe2=\xb1]\xb4\xe4\x03\x0c\xf7\xa5\x14\xa0\x84\x92Z\x03\x07i\xfb""\xbc\x00\xf7\xbe\xbd$$M\xe9\xf8L\xf7\xe0s!\xdfq\x17\x12\x91hY\xc3~0!\x10d?V\x9eaU\x88\xca\xef~\xf3\x17,eEA\xf0\x00p-:\xd1\xe1\x85I\x12ue\x0fTU\x02\x03\x01\x00\x01\xa3-0+0\x1b\x06\x03U\x1d\x11\x04\x140\x12\x81\x10smhaunch@mac.com0\x0c\x06\x03U\x1d\x13\x01\x01\xff\x04\x020\x000\r\x06\t*\x86H\x86\xf7\r\x01\x01\x04\x05\x00\x03\x81\x81\x00@\xca\xe0\xd6}\xa9]U\xadx\xfe\xc1\x06?\x8f\x93u\x1fb\xd6\xee\x1d\xbe6\xb8w\x0b&7\xe3\x9d\x19G\xec\x0cgK\n\xdd/q\xc4\x0fm9\xc3p\xaa\xf1>\xed\xcd\\H\x8d\x14K;\xf9c\xabA\x9eu \x85\x06L\xbby\x8a5>\xb5\xe1\xce\xd1\x87\t4\x81\x86\xc8\x96v,\x8b[\x12\xa5;\x11\x80\xc0\x97?\x94\xc3\'\xc2\xa2\xcev\xb4\x1c\xa0_\xd8\x81\xb8\xdeiANA\xb5!\xf7\x8c=T3iY\x96\x02g\x070\x82\x03?0\x82\x02\xa8\xa0\x03\x02\x01\x02\x02\x01\r0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x05\x05\x000\x81\xd11\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1\x150\x13\x06\x03U\x04\x08\x13\x0cWestern Cape1\x120\x10\x06\x03U\x04\x07\x13\tCape Town1\x1a0\x18\x06\x03U\x04\n\x13\x11Thawte Consulting1(0&\x06\x03U\x04\x0b\x13\x1fCertification Services Division1$0"\x06\x03U\x04\x03\x13\x1bThawte Personal Freemail CA1+0)\x06\t*\x86H\x86\xf7\r\x01\t\x01\x16\x1cpersonal-freemail@thawte.com0\x1e\x17\r030717000000Z\x17\r130716235959Z0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA0\x81\x9f0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x03\x81\x8d\x000\x81\x89\x02\x81\x81\x00\xc4\xa6<UsU\xfbN\xb9\xca\x99Z\x1eh\xc0u\x04p\x9d\xdf\xe9\xff\xa3\x1e\xec\xbd\xcd\xf5[\xf2\x1av\xbd\x7f\x0c:a\xf2\xbfQ\xce\x01\xd4\xe5P\n0\xd7\x02cZ,\x89\x15p\x8e\xdd\xc9\xf0+\x85Z\xaa?qV\xcb\xaf<\x0b\x07\xe7\xf1\x1f\x916$*\x13\xcf+\xd5\xf3\x82w=\x03\xbe+\xfe\xbb\x18>\x07\xbf@\x80\x02d\xd7\xa7\xa6\xbb\x9fe\xd1\xc5*T\x85\x0fH\x04\x7f\xa7\xb6\xd1<a\x04@\x1ed\x19r`\xb7\xfb\x02\x03\x01\x00\x01\xa3\x81\x940\x81\x910\x12\x06\x03U\x1d\x13\x01\x01\xff\x04\x080\x06\x01\x01\xff\x02\x01\x000C\x06\x03U\x1d\x1f\x04<0:08\xa06\xa04\x862http://crl.thawte.com/ThawtePersonalFreemailCA.crl0\x0b\x06\x03U\x1d\x0f\x04\x04\x03\x02\x01\x060)\x06\x03U\x1d\x11\x04"0 \xa4\x1e0\x1c1\x1a0\x18\x06\x03U\x04\x03\x13\x11PrivateLabel2-1380\r\x06\t*\x86H\x86\xf7\r\x01\x01\x05\x05\x00\x03\x81\x81\x00H\x8c\xd1P\x83\xea\x0b.\xcc\r\xa3f\xacg\x0f\x7f\xaf\xac\xbe\xc2\x17\xa1C\x96\x94\x9d\x7fL!\xb8\xf86\x1f\xaa-\x9f6/\xc0\xf4\x1cP \x93p<\xfd\xad\xe1ab\xc3\xd9:\x19~\x84\xb1\x99\x1b\x00\xc5\x1a\x0b\x82t\x9e%P\x94b\xc7\xdb\'qW%\x8d\xdd\xa9\x9c9\x8e\x8c Oe_\x95\xda\xf7\xf7\x87\xd6\xc6\x08N\xae\xf6\xea4\xe5\x10\x1a[5Mw\xe3V!x\x82\xdc!\x195\xde$\xb1\xd3\x1dF\xff]_eO1\x82\x02\xe70\x82\x02\xe3\x02\x01\x010i0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA\x02\x03\x0e\\\xf90\t\x06\x05+\x0e\x03\x02\x1a\x05\x00\xa0\x82\x01S0\x18\x06\t*\x86H\x86\xf7\r\x01\t\x031\x0b\x06\t*\x86H\x86\xf7\r\x01\x07\x010\x1c\x06\t*\x86H\x86\xf7\r\x01\t\x051\x0f\x17\r050508181746Z0#\x06\t*\x86H\x86\xf7\r\x01\t\x041\x16\x04\x14\x12\x90oc\xeb\xe8A\xd2\x92\xa9}_m\n/\xe2?\x9fl50x\x06\t+\x06\x01\x04\x01\x827\x10\x041k0i0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA\x02\x03\x0e\\\xf90z\x06\x0b*\x86H\x86\xf7\r\x01\t\x10\x02\x0b1k\xa0i0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA\x02\x03\x0e\\\xf90\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x04\x82\x01\x00&\xd4g\x85\xed\xd5\x9f2\xfa\xd6\xf3#\x0f\x8eHD\xf9\x1f\x03\xd4;"\n\x85\x92\n\x9f\xb9\x80\x04&\xeeW\n\xed]\xca\xad\x98y\x86\x8c\x1f\xa4\x8d\xd3\x98&Tm\xb6\x8c\xc4\xe1\xfe\xed\xa2\x91*\x91^\x9b\x1a\x01c\x94<\xaep\xa4n\x98?\xfb\xef\xfe0\x8d5O\xafa\x17\xfa\xe02j\xc6r\xbb\xf6|\x862\xf0F\x80D\xb1\xb4\xc5EEI\x91\xd2?\xe3PI\x8c\xf4M9\xa1\xe1\xc0\x04Hs3cr@\x9cs\xa8RK\x8f\xca_\x11^\xb8\xa6c\\\xe7\xd2W\x1e1ypy\x94h\xba#\xc6\xb8\xf3e\xd6\x14\n\xc3\xc3\xfe\x1a\x13\x82\xe6\x82\xe53\xbdT\xb5+g\xaeY7?\xd8*_\x9b\xfbN>\xc7\xc7N{\xa1W\xd8\xf0S\x1e\xbe<F\xc1M\xc4+\x94\xdc\xccw\xb3\x1d\xb5\x96\x81<\xae\x9b\xd9ve\x06\xd4B\xc0\xc9\xc5)\xe2\x0fpL\xe3\xa0\xb5U\xc6\xc3,\xf6\xa8\xb4\x06t}6\x0bf,\xd0~naqa\x1b}\x85s\x91,\xcb\x00\x00\x00\x00\x00\x00',
        ),
        ],
    from_values=EmailAddress(name='xxxxxxxxx xxxxxxx', email='xxxxxxxxx.xxxxxxx@gmail.com'),
    to_values=(EmailAddress(name='xxxxx xxxx', email='xxxxx@xxxxxxxxx.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='xxxxxxxxx xxxxxxx', email='xxxxxxxxx.xxxxxxx@gmail.com'),),
)