"""

If you want to save message as .eml file, work with MailMessage.obj - it is email.message.EmailMessage

python email lib docs:

    https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.as_string
    https://docs.python.org/3/library/email.message.html#email.message.EmailMessage.as_bytes

"""
