import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Impress your clients with a business phone��� ',
    from_='info@here2there-travelers-msgs.net',
    to=('anyone@YAHOO.COM',),
    cc=(),
    bcc=(),
    reply_to=('44.41.17.14.11.2010.1139.1.328.1477949.614@reply.here2there-travelers-msgs.net',),
    date=datetime.datetime(2010, 11, 14, 17, 41, 44, tzinfo=datetime.timezone.utc),
    date_str='Sun, 14 Nov 2010 17:41:44 +0000',
    text='',
    html='',
    headers={'x-ymail-umid': ('1_132725_AEe3iGIAAGS4TOAfWQ3foSiBC54',), 'x-apparently-to': ('anyone@yahoo.com via 98.136.183.71; Sun, 14 Nov 2010 09:41:45 -0800',), 'message-id': ('<201011141741.oAEHfiKs020181@app9.msg2u.net>',), 'mime-version': ('1.0',), 'content-transfer-encoding': ('binary',), 'content-type': ('multipart/alternative; boundary="_----------=_128975650412616235"',), 'x-mailer': ('MIME::Lite 3.020 (F2.73; T1.21; A1.77; B3.01; Q3.01)',), 'date': ('Sun, 14 Nov 2010 17:41:44 +0000',), 'from': ('Biz Phone Systems from EclipseMediaOnline\udcef\udcbf\udcbd\udcef\udcbf\udcbd  <info@here2there-travelers-msgs.net>',), 'to': ('anyone@YAHOO.COM',), 'subject': ('Impress your clients with a business phone\udcef\udcbf\udcbd\udcef\udcbf\udcbd\udcef\udcbf\udcbd ',), 'reply-to': ('Biz Phone Systems from EclipseMediaOnline\udcef\udcbf\udcbd\udcef\udcbf\udcbd  <44.41.17.14.11.2010.1139.1.328.1477949.614@reply.here2there-travelers-msgs.net>',)},
    attachments=[],
    from_values=EmailAddress(name='Biz Phone Systems from EclipseMediaOnline��', email='info@here2there-travelers-msgs.net'),
    to_values=(EmailAddress(name='', email='anyone@YAHOO.COM'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='Biz Phone Systems from EclipseMediaOnline��', email='44.41.17.14.11.2010.1139.1.328.1477949.614@reply.here2there-travelers-msgs.net'),),
)