import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Mail.Ru – больше, чем почта. Познакомьтесь с проектами Mail.Ru Group',
    from_='welcome@corp.mail.ru',
    to=('imap.tools@mail.ru',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='',
    text='Здравствуйте\r\n',
    html='<html>\r\n  <head>\r\n    <meta http-equiv="content-type" content="text/html; charset=utf-8">\r\n  </head>\r\n  <body bgcolor="#FFFFFF" text="#000000">\r\n    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">\r\n        \r\n    <div style="line-height:0;font-size:0;"><img\r\n                src="cid:part1.02000503.06000807@mail.ru" alt=""\r\n                style="width:28px;height:1px;" height="1" width="28"></div>\r\n\r\n    <div style="line-height:0;height:25px;" class="mmwe3-mso_lh5"><img\r\n                src="cid:part51.09060808.01070700@mail.ru"\r\n                style="width:125px;height:25px;" alt="@Mail.Ru"\r\n                height="25" width="125"></div>\r\n                \r\n    <div style="line-height:0;height:60px;" class="mmwe3-mso_lh4"><a\r\n                        href="https://www.odnoklassniki.ru/pochtamail"\r\n                        title="Одноклассники"><img\r\n                          src="cid:part41.01020108.09060604@mail.ru"\r\n                          style="width:60px;height:60px;"\r\n                          alt="Одноклассники" height="60" width="60"></a></div>\r\n\r\n  </body>\r\n</html>\r\n',
    headers={'to': ('imap.tools@mail.ru',), 'mime-version': ('1.0',), 'from': ('=?UTF-8?B?0JrQvtC80LDQvdC00LAg0J/QvtGH0YLRiyBNYWlsLlJ1?=\r\n <welcome@corp.mail.ru>',), 'subject': ('=?UTF-8?B?TWFpbC5SdSDigJMg0LHQvtC70YzRiNC1LCDRh9C10Lwg0L/QvtGH0YLQsC4g?=\r\n =?UTF-8?B?0J/QvtC30L3QsNC60L7QvNGM0YLQtdGB0Ywg0YEg0L/RgNC+0LXQutGC0LA=?=\r\n =?UTF-8?B?0LzQuCBNYWlsLlJ1IEdyb3Vw?=',), 'content-type': ('multipart/alternative;\r\n boundary="------------080400030209020702000207"',)},
    attachments=[
        dict(
            filename='blank.png',
            content_id='part1.02000503.06000807@mail.ru',
            content_disposition='inline',
            content_type='image/png',
            payload=b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x08\x00\x00\x00\x08\x01\x00\x00\x00\x00\xect\x83&\x00\x00\x00\x02tRNS\x00\x01\x01\x94\xfd\xae\x00\x00\x00\x0bIDATx\x01c\xfc\x8f\n\x01@\x18\x08\x01\xdez\xda\x08\x00\x00\x00\x00IEND\xaeB`\x82',
        ),
        
        dict(
            filename='sm-ok.png',
            content_id='part41.01020108.09060604@mail.ru',
            content_disposition='inline',
            content_type='image/png',
            payload=b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00<\x00\x00\x00<\x08\x03\x00\x00\x00\r")@\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x01\xd1PLTE\xffs\x01\xfft\x03\xffu\x06\xff\xf7\xf0\xff\x84!\xff\x93<\xff\xf3\xe9\xff\xfc\xf9\xff\x94>\xff\xde\xc3\xff\xdd\xc1\xff\xf5\xed\xff\xda\xbc\xff\xc8\x9b\xffs\x02\xff\xf8\xf3\xff\xael\xff\x906\xff\xfc\xfa\xff\xef\xe2\xff\xf0\xe3\xff\x8b-\xff\xf4\xec\xff\xa2W\xff\x94=\xff\x81\x1c\xff\xc8\x9c\xff\xeb\xda\xff\xd7\xb7\xfft\x04\xff\xba\x83\xff\xcc\xa2\xff\x9fQ\xff\xd1\xac\xff\xfd\xfb\xff\xfb\xf8\xff\xf6\xef\xff\xd0\xaa\xff\xa3Y\xff\x92:\xffy\x0c\xff{\x10\xff\xbd\x87\xff\xee\xe1\xff\xf3\xea\xffv\x08\xff\xeb\xdb\xff\x9bK\xff\xa2V\xff\xc9\x9d\xff\xc1\x8f\xff\x9cL\xff\xf7\xf1\xff\xfa\xf6\xff\x8f5\xff\xf1\xe6\xff\xee\xe0\xff\xd7\xb6\xff\xc9\x9e\xff\xa3X\xff\xc7\x99\xff\xadj\xffu\x05\xff\x8e3\xff\xadk\xffz\x0f\xff\xa0S\xff{\x11\xff\xdd\xc2\xff\xf8\xf2\xff\x929\xff\xdc\xbf\xff\x93;\xff\x8e2\xff\xdc\xc0\xff\x97C\xff\xcf\xa9\xff\xba\x82\xff\xc7\x9a\xffy\r\xff\x83\x1e\xff\xa4[\xff\xa8b\xff\x8d0\xff|\x12\xff\x88\'\xff\xb7}\xff\xc3\x93\xff\x9fR\xff\xed\xdf\xff\x86%\xff\x96B\xff\x8c/\xff\xd3\xb0\xff\xca\xa0\xff\xa9c\xff\xaci\xff\xe8\xd5\xff\xbf\x8c\xff\xed\xde\xff\xaem\xff\x918\xffv\x07\xff\xbf\x8b\xff\xdb\xbe\xffx\n\xff\xafo\xff\xc3\x92\xff\x95?\xff\xca\x9f\xff\xbd\x88\xff\xc6\x98\xff\x81\x1b\xff\xd6\xb4\xff\x9aH\xff\xec\xdd\xff\xd3\xaf\xff\xd9\xbb\xff\xf9\xf5\xff\x8d1\xff\xf9\xf4\xff\xc5\x96\xff\x907\xff\xf0\xe4\xff\xa9d\xff\xaae\xff\x8a,\xff\xd2\xae\xff\x95@\xff\xfd\xfc\xff\x83\x1f\xff\xd6\xb5\xff\xd8\xb8\xff\xa0T\xff\xc5\x97\xff\xbe\x89\xff\xbe\x8a\xff}\x14\xff\x96A\xff\xa4Z\xffz\x0e\xff\xf6\xee\xff\x84 \xff\xce\xa7\xff\xd4\xb2\xff\x9aI\xff\xcd\xa5\xff}\x13\xff\xf2\xe7\xff\xa1U\xff\x8a+\xff\xbb\x84\xff\xd4\xb1\xffr\x00\xff\xff\xff\xe4\xd8\x99$\x00\x00\x03\xcbIDATx\xda\xac\x97g_\x13A\x10\x877\xb9\x90J\x08\x81P\x12i!\x14)J/J\x17\xa5*\xa0" \x08*J\xb5\xf7\xde{\xefe\xf6\xd3:sg\x80d\xe7\x92X\xe6\r\xfbc\xe6\xc9\xee\xed\xee\xfcgVH\xd6\xb4\x82\xa2\x8e\xdb\xc1\xed\x00\xdb\x83\xfe\x8e\xa2\x02\x8d\x8f\x12\xcc\xff\x02\x8b\x95\x16\x881K\xe5bMJ\xb0\xbb)\x8e\xfc\xcd7\x8d$\x85\x07\xf3\xf5\xd0\x8c\xe1\xcc\x90\xab\xdd\'\xa5\xaf\xdd\x15\xca\x1c\xce\xd0\xff\x99?\x98\x10n;HA\xc2\xd9Y\x1b\x1bU\xdb\xe9\x14\xe49\xd8f\x0e\x97\xf7a\x80\xf5\xf86ns\xb6\x1d\xb7\xa2\xb3\xaf\xdc\x04vd\xd2\x8f\xe7\xd5H\x13\xcb\xee \x7ff\x84\x83\xf7\x8d\xa2\xcb\x96.\x13X\xba\rC\x9c\x1e\x15\xae\xedAGI\x99Lhe3\x18t\xac6\x1e\xd6\x86q\xa3\xce\xcb\xa4v\x1e7\xee\x86\x16\x0b;\xe6\xf0$\x8be\nV\x8c\xb7`\xce\x11\x03w\xe1\xbc\x9d2%\xeb\xc4\xb9\xbb\xb6\xc2\xe5\xf8)\xd52E\xab\xc6\xe0\xfd\x9b\xf0\x9d*\x80\x19\x99\xb2\xed\x01\xa8\nl\xc0%xFZ\xea\xb0\x86\'V\x12\x85Wq\x1d\xe9\xf2\x0f,\xfd7@p\x1a@\x05\x1btr~\xfe$\xeb\xa8\x00H3`7\xc0\x8el5\xc0q\xe6=]G\xdb\x99,\xe6\xa6\xee\x00p\xebp\x13@\xaf\xea\xffZ\x19\xcd\xe4!\xbb\xea\xed\x05h"\xd8^\x08B\xcd\xa3\x96c\x9b:p\xb8Eq\xef\x14PhG\xb8\x11\xb3\\\xfd\xe9)C\x13\x0c\x15\x98R\xfdN\x80F\x84q\xbb\xc6\x14_V?2\xe3\xc5\x91H\xf18\x0e&\xd5\xcf\xf6\xd2\x96\t\xcd\x02B\xfd(7M\xf8\x81F\x9fi\xb4W\t\xb0\x0b\xb0hb\x17@\x8e\xba\xaa\xddH,\xeb\xf3e\x91\x80,\xa8\x119\x00\xbb\xc4\x0f\x80\xd3\xaak\x8c\xf4H\x87\x1d\x04{\xd5\x08\x94\x9d\x03"\x0f $\xf9e\x9f\x8b\xae\x81Y\xb6l@\xc5\x12~\x00\x97\xea*\xfd\x82\xc8\xda\xf3\xe6\xe6[k8x\xf5H\x8dp\x01\xf8E\x10\xe0(s\x01\x0fl\x15\xfc"&\xe0\x14\xc0E\x81\xf5h\x1f\xe3s\xa4m\xb2\xf9\x0e& \x17\x8f\x92\xb4\x9c\xbd\xfb\x9e\xd1(;\xea\xe1\xfc\x0e\xaa\x0ef\xb0,\r}\'\xf4~C\xa94\x81\xad\xb4l\x1f3\xef\xb902\xd9{]\x98n\xa5\xe1\x05\x0f\xbb\xecI~\xc3|\x13\x00\xb3\r:\xe2\t\xcd\x02L\xf8\xb8\r{\xcc\x1f\xd5\x13#-\x8e\x9c={\xc4H\x8d\x02\xfe\xa8\xf0\x92\xecV\xabZ\\\x89.\xdc\xc9]\xe0<Q\xc4^\xcfpp+\x1b\x0c\x9b\\O>1d\xcbtO\x14\xed\x99n\x91&\x89\xc1\xa7$\xd9\x05\x83\x1dc\x9d\x94\x92e\xba\x18x9\xf7G\xab\x01/_\xe2\xbc\x86\x18\x90\x0c9\x19\xefUkt\xd9\xd6\x9f\xd2T\x86H\x00\xd5\xcd\x0c\xeb\xac\xbfU\xa7\x1f\x98\n\xa0\xac\xc3^!\xdeYPHT\xa5\xa6\r\xd0\xdf\xee\xa7\xcc^\xd7m\x88~ \xcey\x99\x984L\xb7\xe6!\x1a}2\x15}\xae\xdc\xd4S\xf3\xa1\xdfI\x1f5f\xf5\xa6\xe5f\xa3nm\xb1\xf6%k\xc7ucx3\xcf\xba\x94\xad\x16\xbak\xff\xa3\xc4\xca\x00\x16\xf7=\x7f[\xdc\xe5\xfe\x7fh+\xa4<\x81\x9a\xe2M\x8d\xf5\xa2\xf8\x9c\x88m\xa5\x1e\xfeI+\xe5\x8cm\xa5d.f\x89x\x91\x9c}\x89\xf3\xe6\xe4\xc6\xb7\x8f\xf6\xc3\xf8)\xcf\x92\xb5\x8f\xdf0(\xc7\xae6\xae\xcd\xaf\xa9\x89p\'b\xdd\xd4\xb8\xe6{\xb8\x969\xd2KR|(`\x86\x06\x0e\x91NwE\x126\xebw\xf9f\xfd\x1e\xe5\xd9\xdb\xf2\x04\xcf\x847\xc63\xc1\x9b\x1b\'\xd2^\xe3\x99P\xd1\x96\xf8\x81b\xd4(K\xeb\xba\xfe@\xc9zw\xc5\xd5\xb0\xee7\xc4th5\xe9\xd3h\xa4.\x83{\x1ae\xd4%\x7f\x1a\x91\xd5\xac\x0c\xc4?\xca\x06VR{\x94E\x9f\x83\xf5\xad\xb6\xfe\xee\xee~[k\xbd\xe9s\xf0\x97\x00\x03\x003\xa2}\xdf\xee~*\xa5\x00\x00\x00\x00IEND\xaeB`\x82',
        ),
        
        dict(
            filename='logo.png',
            content_id='part51.09060808.01070700@mail.ru',
            content_disposition='inline',
            content_type='image/png',
            payload=b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00}\x00\x00\x00\x19\x08\x03\x00\x00\x00+;\xd1[\x00\x00\x00\x19tEXtSoftware\x00Adobe ImageReadyq\xc9e<\x00\x00\x00fPLTE\xfd\xfd\xfd\xfe\xfe\xfe\xf3\xf3\xf3\xec\xec\xec\xe8\xe8\xe8\xdf\xdf\xdf\xf1\xf1\xf1\xfc\xfc\xfc\xee\xee\xee\xe2\xe2\xe2\xfb\xfb\xfb\xf7\xf7\xf7\xe0\xe0\xe0\xf5\xf5\xf5\xed\xed\xed\xf2\xf2\xf2\xf9\xf9\xf9\xeb\xeb\xeb\xe6\xe6\xe6\xf4\xf4\xf4\xef\xef\xef\xf6\xf6\xf6\xf8\xf8\xf8\xe7\xe7\xe7\xe3\xe3\xe3\xe5\xe5\xe5\xea\xea\xea\xfa\xfa\xfa\xe4\xe4\xe4\xe1\xe1\xe1\xf0\xf0\xf0\xe9\xe9\xe9\xde\xde\xde\xff\xff\xff\xe4X/e\x00\x00\x03-IDATx\xda\xc4\x96\xd9\x96\x83 \x0c\x86\xc5\r\x17\xd4\xba\xef-\xbc\xffKN\x12@mG\xcf\x1c\xe7b\x86\x8b\x9e\x8a$_H~\x82\x8e\xb2\x83\x87\xfe\x10H1L\x85\xa3n\x8e$\x0ej\xa5|\xe9\xdd5\xb4$\xee\x05\xd2\x8e\xc0\xbb\xc9\x0f\xa5\xf4U\x02\x96\xbf\xa4g\x02\xb1b\xa9\x06\nbmo9\xc9\xa4,\xef\xd1\x1fE\xd1m\xf4\'\x12\x9b\x19\xff\xb2v\xc2\x00\xdc{x\x97\xdd\xa3\x870,\xdd\x05\xc3\x12\xff1z5W\xf0\x9c\xe9\x8a\x82\x08:\xd7Mt\xbc.?D_\x17\x19\x980\x17\xf7\x90B\xd9\xcf\xe9`\x0cN\xebc.3p]4Ma\xe83l\xb6\x81\xd2\xe7\xb1\x94C\x84.KH\x05\xc55\xc8q\xc0R\xbc\x9cn$E\xe8\xf8T\x11\x93B\xfc\xd9\x93\xb2S)\xda\x9f\xd0Y\x88\xcbJUHYo\x93\xf4\xe0\xd6\xb5\xa5\xfbRN\xb6\xf4P\xfcl\x899L\xe5\xf8vSblD\xd9\x93X\xfcM\xa0+\x16\xe9BuNOk^\nB\x8c\xb6Y\xfd\x90\xccFu3\x109*GVy\xae\rR\x0eg\x8f\x19\xba\x98\xf4\xe4:\xe1\xf6!d\x86\x95\x11\xfeT\xe9\x08\xae\xe8l\xa4e9?\xa3o\x9a\x8fp\x9f\\HA\xc5y`\xb2R\\\x93i\xfa\x0b\x96@%\xe4\x04\xd1\xf4\xb4\xf9\x06\x9erf\x05rI\xcfa"b\x9f\xc0O:\xb8x\xe0RS\x1aTA\xaaZJ=\xd2QiPX\xe9hy\xc6\xca\x11$\x93m{\x17tH\x9f\x0c\xbf\x03?\xe9\xb0k\xa5bpk\xc6\x84t\x8e\x0e\x89\x8e\xd4\x87\xf1\x9c!\xbd\x06m2\xab\xfck:L\x8e\xeag:8S\x8c\x84\xb7\x99\xa58\xbb\\\xd0\xa3\xa3\xaf\xe1\x92>m[\xff\x81\xbe \xa6<\x1c\x89\x14\xc3\xb9\xa2\x97$=3\xfaK:\xbciw\x05\xbc\xd1\x9b\xb7\xcc\xaf\xf8\xd3\x1f\xd4\x92\xa2\xaf\xea\x82\x9e\x1f\xcc\xd5rI\xaf(\x85\xb6\x95n{S\xafC\xf0\xe0\x1b\x94\x93\xc0\\`\x1a\x99\xb3\xa2YM\x06\xa7tw/(!\r\xdd*\xf4\x84\x0e\x12\x8e\xadRP\xb3\xdd\xfb\x89\x0bU\x07g\x89\x160\x9fN\x9cN\xef)\xdd\t\xf6\xd6\xf5\xda\xe9j\xdd\x0b\xfdAg\xfb)\xc1\xc4\xc7\xc7;\xae#\rC\x0c\x8b;\xcf\xeeb\xbb\r\xe6\xe2\x94\x8e\xa9\x0f\x08\xcf\xbc\xc3yG\xbfA{J\xa7[\xac\xc1\xcd\xb1H\x1eU\x83\xbeG\x8a\xcc\xb3\xdd\x136\x1f\xe9\xe6{Ag\x18\xe1\xd8\x84\xdez\xecu\xd8\xb0 \x81y\x8a\xe1U\xec\x8dN\xdd1\xceC\x0f[\x99\xff~\xbfw\xfaFm\xb1u\xc81c\xd4\xd2\x05\xbf\xa4\xabd\x90\x87a\xe9\xaa%C\xc8\x99\xc0\xfeu\xa4+\xa7\xda\x96\xf7\xce\xc7\xd7Ecz"OSdbv\x84\xb6\x142`Z\\B\xe98\x17\xb22\x89\x8a\xdd\t\xcfUm4\xddQ\xd98\xb4.\xd21\x84\xb07\xfdF_S\xe2\xc9\xbe}\xdb`\x1f\x8f\x9f\xa4X\x96>TV\xe6\x89~\x9d\x96\xba\x92\x99\xa7u\xeaz\xc6#/\xf22j\x19|\x91\xa1\xd2\x9e\xb9Q{\x1b\x955ZA*\x13\xafx\xbf\xf1j\xb0\xa8\xd9\xd9\x97\xd5\x93"\x1bz\xbf\n\xb6\xa3\xf7\x07\xc3\x16a\xf6\xf7\x8f\xca\xbf\xa7C\xa6\x9e>\xd4+\x18\xca\x87\xfa\x07\xfa\x7f\x8c/\x01\x06\x00\xcc\x9eX\xf3u\xe2\x94\xf6\x00\x00\x00\x00IEND\xaeB`\x82',
        ),
        ],
    from_values=EmailAddress(name='Команда Почты Mail.Ru', email='welcome@corp.mail.ru'),
    to_values=(EmailAddress(name='', email='imap.tools@mail.ru'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)