import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Microsoft Vlsta & Office2007, Just released for 79$ Save 1599.95$ 0ff Retai|',
    from_='subventive@vodtravel.com',
    to=('sydney@xxxxxxxx.xxx',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(1900, 1, 1, 0, 0),
    date_str='Pn, 29 paX 2007 21:13:00 +0100',
    text='hotnewsoft . com\r\n\r\n\r\n\r\n\r\n',
    html='',
    headers={'return-path': ('<me@xxx.xxxxxxxx.xxx.xx>',), 'x-original-to': ('external@xxx.xxxxxxxx.xxx.xx',), 'delivered-to': ('external@xxx.xxxxxxxx.xxx.xx',), 'received': ('from server.xxx.xxxxxxxx.xxx.xx (localhost.xxxxxxxx.xxx.xx [127.0.0.1])\r\n        by server.xxx.xxxxxxxx.xxx.xx (Postfix) with ESMTP id 0173828456\r\n        for <external@xxx.xxxxxxxx.xxx.xx>; Mon,  5 Nov 2007 20:17:37 +1100 (EST)', 'from server.xxx.xxxxxxxx.xxx.xx (server.xxx.xxxxxxxx.xxx.xx [10.130.1.250])\r\n        by localhost (FormatMessage) with SMTP id d7be4d19ed6d330c\r\n        for <sydney@xxxxxxxx.xxx>; Mon, 05 Nov 2007 20:17:37 +1100 (EST)', 'from server.sydney.xxxxxxxx.xxx.xx (unknown [10.130.2.6])\r\n        by server.xxx.xxxxxxxx.xxx.xx (Postfix) with ESMTP id BB00328442\r\n        for <sydney@xxxxxxxx.xxx>; Mon,  5 Nov 2007 20:17:37 +1100 (EST)', 'from dircomm (unknown [10.130.2.8])\r\n        by server.sydney.xxxxxxxx.xxx.xx (Postfix) with ESMTP id 20A692841F\r\n        for <sydney@xxxxxxxx.xxx>; Mon,  5 Nov 2007 20:18:24 +1100 (EST)'), 'x-mailbox-line': ('From subventive@vodtravel.com',), 'message-id': ('<000001c81a67$a4450700$0100007f@localhost>',), 'from': ('"Darrell Shaw" <subventive@vodtravel.com>',), 'to': ('<sydney@xxxxxxxx.xxx>',), 'subject': ('Microsoft Vlsta & Office2007, Just released for 79$ Save 1599.95$ 0ff Retai|',), 'date': ('Pn, 29 paX 2007 21:13:00 +0100',), 'content-type': ('text/plain;\r\n    charset="us-ascii"',), 'content-transfer-encoding': ('7bit',), 'x-priority': ('3 (Normal)',), 'x-msmail-priority': ('Normal',), 'x-mailer': ('Microsoft Outlook, Build 10.0.3416',), 'importance': ('Normal',), 'x-mimeole': ('Produced By Microsoft MimeOLE V6.00.2800.150',), 'x-csi-tmailscanner-information': ('Please contact the ISP for more information',), 'x-csi-tmailscanner': ('Found to be clean',), 'x-csi-tmailscanner-spamcheck': ('not spam, SpamAssassin (score=1.87, required 4,\r\n        autolearn=disabled, INVALID_DATE 0.23, RAZOR2_CF_RANGE_51_100 1.49,\r\n        RAZOR2_CHECK 0.15)',), 'x-csi-tmailscanner-spamscore': ('s',), 'x-tmailscanner-from': ('subventive@vodtravel.com',), 'resent-date': ('Mon, 05 Nov 2007 20:17:37 +1100 (EST)',), 'resent-from': ('<mail_dump@ns1.xxxxxxxx.xxx.xx>',), 'resent-to': ('<mikel@xxxxxxxx.xxx>',), 'resent-message-id': ('<d7be4d19ed6d330c.1194254257@xxxxxxxx.xxx.xx>',), 'x-uid': ('4702',), 'status': ('RO',)},
    attachments=[],
    from_values=EmailAddress(name='Darrell Shaw', email='subventive@vodtravel.com'),
    to_values=(EmailAddress(name='', email='sydney@xxxxxxxx.xxx'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)