import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='bookkeeping Get in on IGTS asap.',
    from_='baocqccyw@hq.lindsayelec.com',
    to=('em-ca-bruceg@em.ca',),
    cc=(),
    bcc=(),
    reply_to=('baocqccyw@hq.lindsayelec.com',),
    date=datetime.datetime(2005, 3, 27, 19, 11, 59, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=64800))),
    date_str='Sun, 27 Mar 2005 19:11:59 -0600',
    text='acidness\r\n\r\n          Exciting Easter Investor Alert\r\n\r\nTicker:IGTS\r\nCurrent:0.01\r\nRating:Big Mover Next Week\r\n\r\nThis st0ck receives our top rating - 10 out of 10\r\nBreaking NEWS (released last night): Intelligent\r\n\r\nSports, Inc. Offers Affordable Alternative\r\nThis is the first news release the company put\r\nout since November - this is going to be exciting\r\nstock play\r\n\r\nJump on board while you can - Don\'t regret It later\r\n\r\nAbout the Company:\r\n\r\nYouth And Amateur Sports Company Poised For Growth \r\n\r\nIntelligent Sports, Inc. is a publicly held company\r\ntrading on the OTC markets under the ticker symbol\r\nIGTS. Intelligent Sports will be the holding company\r\nfor several sports related businesses. Intelligent\r\nSports provides business units with strategic guidance\r\nand support in the areas of marketing, sales,\r\nsponsorships, partnerships, policy & procedures,\r\nfinance and expansion. Their initial business launch\r\nis to develop youth and amateur sports centers\r\nthroughout the country that offers a year-round\r\nsports calendar with emphasis on youth and amateur\r\nsports programs and skill development. Their plan\r\nis to expand this concept into membership-based,\r\nmulti-purpose sports facilities that will promote\r\na diverse range of sports programs, leagues,\r\ntournaments, clinics, individual sports skill\r\ndevelopment and nutritional training.\r\n\r\nFresh News:\r\n\r\nUPLAND, Calif., Mar 22, 2005 (PRIMEZONE via COMTEX)\r\nParticipation fees for school sports programs\r\ncontinues to escalate, at the same time record\r\nobesity levels in children are being reported by\r\nthe Center for Disease Control. Intelligent Sports,\r\nInc. (Pink Sheets:IGTS) is working to do their part\r\nto curb this alarming trend of by offering affordable\r\nfitness centers to kids. \r\n\r\n"The time when school sports programs had enrollment\r\nfees of $10 is fading," said former NBA star and\r\nIntelligent Sports, Inc. board member, Reggie Theus.\r\n"Not every parent is willing to pay $300 enrollment\r\nfees for a sport their child is only casually\r\ninterested in; some parents can\'t afford to pay that\r\nmuch for a sport their child excels at."\r\n\r\nAccording to the President\'s Council on Physical\r\nFitness and Sports, only 17 percent of middle and\r\njunior high schools and 2 percent of senior high\r\nschools require daily physical activity for all\r\nstudents. Hoping to fill the gap, The Sports Zone\r\nby Intelligent Sports will support a wide range of\r\nmembership-based after-school sports programs,\r\nweekend leagues and tournaments promoting individual\r\nathletic skill development, the concepts of teamwork\r\nand discipline, and a love of the game.\r\n\r\nThe Sports Zone opened in early October in Upland,\r\nCalifornia. It encompasses a 10,000 square foot\r\nfacility featuring two basketball courts and caters\r\nto court sports including basketball, volleyball,\r\ncheerleading, and wrestling, and also has the ability\r\nto host soccer, football and other field-related\r\nathletic activity within the complex arena.\r\n\r\n+++++++++++++++++++++++++++\r\nIGTS is expected to Explode All Next Week Be Sure\r\nTo Get It Immediately, and profit big!\r\n++++++++++++++++++++++++++++\r\n\r\nDisclaimer\r\n\r\nThis publication is not registered investment advisor,\r\nThe information presented above is not an offer to\r\nbuy or sell securities it contains "forward looking\r\nstatements" within the meaning of Section 27A of the\r\nSecurities Act of 1933 and Section 21B of the\r\nSecurities Exchange Act of 1934. Any statements that\r\nexpress or involve discussions with respect to\r\npredictions, goals, expectations, beliefs, plans,\r\nprojections, objectives, assumptions or future events\r\nor performance are not statements of historical fact\r\nand may be "forward looking statements." In compliance\r\nwith Section 17(b), the publishers of this report\r\ndisclose the holding of IGTS shares prior to the\r\npublication of this report. Be aware of an inherent\r\nconflict of interest resulting from such holdings\r\ndue to our intent to profit from the liquidation\r\nof these shares. Shares may be sold at any time,\r\neven after positive statements have been made\r\nregarding the above company. Since we own shares,\r\nthere is an inherent conflict of interest in our\r\nstatements and opinions. Readers of this publication\r\nare cautioned not to place undue reliance on forward\r\nlooking statements, which are based on certain\r\nassumptions and expectations involving various risks\r\nand uncertainties, that could cause results to differ\r\nmaterially from those set forth in the forward- looking\r\nstatements. Please be advised that nothing within this\r\nemail shall constitute a solicitation or an offer to\r\nbuy or sell any security mentioned herein. This newsletter\r\nis neither a registered investment advisor nor affiliated\r\nwith any broker or dealer. All statements made are our\r\nexpress opinion only and should be treated as such. We\r\nmay own, buy and sell any securities mentioned at any\r\ntime. This report includes forward-looking statements\r\nwithin the meaning of The Private Securities Litigation\r\nReform Act of 1995. This newsletter was paid\r\n41 500, from third party to send this report. Please do\r\nyour own diligence before investing in any profiled company.\r\nYou may lose money from investing. caddis worktable\r\n',
    html='',
    headers={'return-path': ('<baocqccyw@hq.lindsayelec.com>', '<baocqccyw@hq.lindsayelec.com>'), 'delivered-to': ('em-ca-bruceg-spam@em.ca', 'em-ca-em-ca-bruceg@em.ca'), 'received': ('(qmail 32184 invoked by uid 700); 28 Mar 2005 01:14:54 -0000', '(qmail 32179 invoked by uid 115); 28 Mar 2005 01:14:54 -0000', 'from baocqccyw@hq.lindsayelec.com by churchill by uid 64011 with qmail-scanner-1.22 \r\n (clamdscan: 0.75-1. spamassassin: 2.63.  Clear:RC:0(200.141.184.56):. \r\n Processed in 10.454045 secs); 28 Mar 2005 01:14:54 -0000', 'from dial.suednet.com.br (HELO hq.lindsayelec.com) (200.141.184.56)\r\n  by churchill.factcomp.com with SMTP; 28 Mar 2005 01:14:42 -0000'), 'from': ('shavonda Cabral <baocqccyw@hq.lindsayelec.com>',), 'to': ('<em-ca-bruceg@em.ca>',), 'subject': ('bookkeeping Get in on IGTS asap.',), 'date': ('Sun, 27 Mar 2005 19:11:59 -0600',), 'reply-to': ('<baocqccyw@hq.lindsayelec.com>',), 'mime-version': ('1.0',), 'x-virus-status': ('Scanned by norton',), 'message-id': ('<41314357824.13240873.93296@oxygen-k19.hq.lindsayelec.com>',), 'content-type': ('text/plain; charset=us-ascii',), 'content-transfer-encoding': ('plain',), 'content-length': ('5102',), 'lines': ('125',)},
    attachments=[],
    from_values=EmailAddress(name='shavonda Cabral', email='baocqccyw@hq.lindsayelec.com'),
    to_values=(EmailAddress(name='', email='em-ca-bruceg@em.ca'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='', email='baocqccyw@hq.lindsayelec.com'),),
)