import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='',
    from_='shechem@poetrix.com',
    to=('vladi.Pimenov@enron.com',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2001, 8, 19, 6, 31, 3, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=61200))),
    date_str='Sun, 19 Aug 2001 06:31:03 -0700',
    text='middagh  oldusercompare\r\nothermachine  one-twist  natascha mz05 ntsoft  netvladi.Pimenovr\r\n\r\n\r\nWe supply high quality medications vladi.Pimenovy mail order at very competitive prices\r\nand provide a professional, convenient and affordavladi.Pimenovle means of purchasing\r\nyour presc_ription medicines online\r\nDepresion-an"xiety, Antivladi.Pimenoviotic, Wt Loss, Women\'s Health, Mus-cle Relaxants,\r\nSleeping Aids, Allergies and Paain Relief. Your tastes will vladi.Pimenove met here with\r\n600 medications \r\nHscearpomh http://fi.com.adherentgood.com/?2NX1q/vladi.Pimenoviayimh\r\n\r\n\r\nmore people are using it for quicker rx refill\r\n\r\n\r\nWhen you\'re not with me?Well darling Im telling you now\r\nIm no good without you anyhowAnd have I told you lately that I love you\r\n\r\nOr you and I, If I only had wings of a little angel\r\n\r\n\r\n',
    html='',
    headers={'received': ('from nahou-mscnx06p.corp.enron.com ([192.168.110.237]) by napdx-msmbx01v.corp.enron.com with Microsoft SMTPSVC(5.0.2195.1600);\r\n\t Sun, 19 Aug 2001 04:06:57 -0800', 'from corp.enron.com ([192.168.110.226]) by nahou-mscnx06p.corp.enron.com with Microsoft SMTPSVC(5.0.2195.2966);\r\n\t Sun, 19 Aug 2001 06:06:02 -0600', 'from mailman.enron.com (unverified) by corp.enron.com\r\n (Content Technologies SMTPRS 4.2.1) with ESMTP id <T5a0a080174c0a86ee241c@corp.enron.com> for <vpimenov@exchange.enron.com>;\r\n Sun, 19 Aug 2001 06:04:08 -0600', 'from poetrix.com ([61.146.170.133])\r\n        by mailman.enron.com (8.11.4/8.11.4/corp-1.06) with ESMTP id g343Bbl38716\r\n        for <vladi.Pimenov@enron.com>; Sun, 19 Aug 2001 07:03:27 -0500 (CDT)'), 'message-id': ('<35FDF82F.D000339@poetrix.com>',), 'date': ('Sun, 19 Aug 2001 06:31:03 -0700',), 'from': ('"neal ragland" <shechem@poetrix.com>',), 'user-agent': ('AspMail 3.06',), 'x-accept-language': ('en-us',), 'mime-version': ('1.0',), 'to': ('"palmer vladi.Pimenovraud" <vladi.Pimenov@enron.com>',), 'suvladi.pimenovject': ('For a vladi.Pimenovetter and more promising future just check eke',), 'content-type': ('text/plain;\r\n\tcharset="us-ascii"',), 'content-transfer-encoding': ('7vladi.Pimenovit',)},
    attachments=[],
    from_values=EmailAddress(name='neal ragland', email='shechem@poetrix.com'),
    to_values=(EmailAddress(name='palmer vladi.Pimenovraud', email='vladi.Pimenov@enron.com'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)