import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Attention',
    from_='nsukijamq@morozstudio.tk',
    to=('cvs@bruce-guenter.dyndns.org',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2005, 6, 29, 22, 57, 10, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=64800))),
    date_str='Wed, 29 Jun 2005 22:57:10 -0600',
    text='Dear Homeowner,\r\n\r\n \r\n\r\nYou have been pre-approved for a $402,000 Home Loan at a 3.45% Fixed Rate.\r\n\r\nThis offer is being extended to you unconditionally and your credit is in no\r\nway a factor.\r\n\r\n \r\n\r\nTo take Advantage of this Limited Time opportunity all\r\n\r\nwe ask is that you visit our Website and complete\r\n\r\nthe 1 minute post Approval Form.\r\n\r\n \r\n\r\nEnter Here <http://www.lending-blocksx.com/index.php?refid=spr>  \r\n\r\n \r\n\r\nSincerely,\r\n\r\n \r\n\r\nEsteban Tanner\r\n\r\nRegional CEO\r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\n \r\n\r\nTuuuuurn oooooff notiiificatiiiiions heeeeeeere.\r\n<http://www.great-mort-gages.com/rem.php> \r\n\r\n',
    html='<html xmlns:o="urn:schemas-microsoft-com:office:office" xmlns:w="urn:schemas-microsoft-com:office:word" xmlns="http://www.w3.org/TR/REC-html40">\r\n\r\n<head>\r\n<META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=utf-8">\r\n<meta name=Generator content="Microsoft Word 11 (filtered medium)">\r\n<style>\r\n<!--\r\n /* Style Definitions */\r\n p.MsoNormal, li.MsoNormal, div.MsoNormal\r\n\t{margin:0in;\r\n\tmargin-bottom:.0001pt;\r\n\tfont-size:12.0pt;\r\n\tfont-family:"Times New Roman";}\r\na:link, span.MsoHyperlink\r\n\t{color:blue;\r\n\ttext-decoration:underline;}\r\na:visited, span.MsoHyperlinkFollowed\r\n\t{color:purple;\r\n\ttext-decoration:underline;}\r\nspan.EmailStyle17\r\n\t{mso-style-type:personal-compose;\r\n\tfont-family:Arial;\r\n\tcolor:windowtext;}\r\n@page Section1\r\n\t{size:8.5in 11.0in;\r\n\tmargin:1.0in 1.25in 1.0in 1.25in;}\r\ndiv.Section1\r\n\t{page:Section1;}\r\n-->\r\n</style>\r\n\r\n</head>\r\n\r\n<body lang=EN-US link=blue vlink=purple>\r\n\r\n<div class=Section1>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>Dear Homeowner,<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>You have been pre-approved for a $402,000 Home Loan at a\r\n3.45% Fixed Rate.<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>This offer is being extended to you unconditionally and your\r\ncredit is in no way a factor.<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>To take Advantage of this Limited Time opportunity all<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>we ask is that you visit our Website and complete<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>the 1 minute post Approval Form.<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><a href="http://www.lending-blocksx.com/index.php?refid=spr">Enter Here</a>\r\n<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>Sincerely,<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>Esteban Tanner<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'>Regional CEO<o:p></o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=2 face=Arial><span style=\'font-size:10.0pt;\r\nfont-family:Arial\'><o:p>&nbsp;</o:p></span></font></p>\r\n\r\n<p class=MsoNormal><font size=3 face="Times New Roman"><span style=\'font-size:\r\n12.0pt\'>Tuuuuurn oooooff notiiificatiiiiions <a\r\nhref="http://mrratenow.com/x/st.html" target="_new">heeeeeeere.</a></span></font><font\r\nsize=2 face=Arial><span style=\'font-size:10.0pt;font-family:Arial\'><o:p></o:p></span></font></p>\r\n\r\n</div>\r\n\r\n</body>\r\n\r\n</html>\r\n',
    headers={'return-path': ('<nsukijamq@morozstudio.tk>',), 'delivered-to': ('cvs@bruce-guenter.dyndns.org',), 'received': ('(qmail 25055 invoked from network); 30 Jun 2005 03:57:11 -0000', 'from localhost (localhost [127.0.0.1])\r\n  by bruce-guenter.dyndns.org ([192.168.1.3]); 30 Jun 2005 03:57:11 -0000', 'from zak.futurequest.net ([127.0.0.1])\r\n  by localhost ([127.0.0.1])\r\n  with SMTP via TCP; 30 Jun 2005 03:57:11 -0000', '(qmail 20286 invoked from network); 30 Jun 2005 03:57:10 -0000', 'from mx-host.dot.tk (unknown [220.173.239.48])\r\n  by zak.futurequest.net ([69.5.6.152])\r\n  with ESMTP via TCP; 30 Jun 2005 03:57:08 -0000'), 'from': ('"Shelby" <nsukijamq@morozstudio.tk>',), 'to': ('<cvs@bruce-guenter.dyndns.org>',), 'subject': ('Attention',), 'date': ('Wed, 29 Jun 2005 22:57:10 -0600',), 'mime-version': ('1.0',), 'content-type': ('multipart/alternative;\r\n\tboundary="----26473166335893217"',), 'x-mailer': ('Microsoft Office Outlook, Build 11.0.5510',), 'thread-index': ('AcT9+CUlRgRKMiKZSj+BjT+PHEf8rQ==',), 'x-mimeole': ('Produced By Microsoft MimeOLE V6.00.2800.1106',), 'content-length': ('7044',), 'lines': ('244',)},
    attachments=[],
    from_values=EmailAddress(name='Shelby', email='nsukijamq@morozstudio.tk'),
    to_values=(EmailAddress(name='', email='cvs@bruce-guenter.dyndns.org'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)