import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Western Union Swift Money Transfer',
    from_='ceciledwards@sbcglobal.net',
    to=(),
    cc=(),
    bcc=(),
    reply_to=('western.uniontransfer1@hotmail.fr',),
    date=datetime.datetime(2009, 12, 3, 10, 50, 22, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=57600))),
    date_str='Thu, 3 Dec 2009 10:50:22 -0800 (PST)',
    text='Attention Beneficiary:\r\n\xa0\r\nThis is to officially informed you that we have concluded arrangements to effect your payment of $1,500,000.00 United States Dollars through WESTERN UNION Swift Money transfer services today, but the maximum amount you will be receiving every day starting from tomorrow is $5,000.00 as reflected in our transfer system daily until the funds is completely transferred.\r\n\xa0\r\nThis special arrangement is being used to avoid all scrupulous demands by both the states and federal authorities that have previously delayed your payment till date; we shall need your maximum co-operation to ensure that strictness and confidence is maintained to avoid any further delays.You are to discard any request asking you to send money to any agency such as courier company,Bank and Security Agency as there are no such and any money committed their will be regret, so be wise. \r\n\xa0\r\nPlease contact the Accredited WESTERN UNION Agent for the details of your first payment of $5,000 United States Dollars and reconfirm your correct details that you will like the first transfer to be program with such as Receivers Name, destination where you will like the transfer to be send to and your cell phone number for urgent communication if the need arise.\r\nFill your details below for reference purposes:\r\n*NAME OF CUSTOMER: .........\r\n*ADDRESS: ..........\r\n*COUNTRY: .................\r\n*TEL: .....................\r\n*OCCUPATION: ..............\r\n\xa0\r\nRemember your obligation to secure an International Remittance Form as stated in United Nation act of (FRT209) that will help build and renew your transfer file for record keeping as a way of checkmating the present Economics crisis situations.\r\nContact the below Electronic Transfer unit of WESTERN UNION for immediate programing of your first transfer:\r\n\xa0\r\nName: Rev.John Ntepe\r\nMobile:+229 97292685\r\nEmail: (western.union1891@live.fr) or (westerrnunion_2@sify.com)\r\n\r\n\xa0\r\nRegards.\r\nThanks and God Bless.\r\nMrs.Cecil Edward\r\n\r\n\r\n-- \r\nFilter4: This message has been scanned for viruses and\r\ndangerous content by MailScanner, and is\r\nbelieved to be clean.\r\n\r\n',
    html='<table cellspacing="0" cellpadding="0" border="0" ><tr><td valign="top" style="font: inherit;"><span style="font-weight: bold;">Attention Beneficiary:</span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">This is to officially informed you that we have concluded arrangements to effect your payment of $1,500,000.00 United States Dollars through WESTERN UNION Swift Money transfer services today, but the maximum amount you will be receiving every day starting from tomorrow is $5,000.00 as reflected in our transfer system daily until the funds is completely transferred.</span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">This special arrangement is being used to avoid all scrupulous demands by both the states and federal authorities that have previously delayed your payment\r\n till date; we shall need your maximum co-operation to ensure that strictness and confidence is maintained to avoid any further delays.You are to discard any request asking you to send money to any agency such as courier company,Bank and Security Agency as there are no such and any money committed their will be regret, so be wise. </span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">Please contact the Accredited WESTERN UNION Agent for the details of your first payment of $5,000 United States Dollars and reconfirm your correct details that you will like the first transfer to be program with such as Receivers Name, destination where you will like the transfer to be send to and your cell phone number for urgent communication if the need arise.</span><br style="font-weight: bold;"><span style="font-weight: bold;">Fill your details below for reference\r\n purposes:</span><br style="font-weight: bold;"><span style="font-weight: bold;">*NAME OF CUSTOMER: .........</span><br style="font-weight: bold;"><span style="font-weight: bold;">*ADDRESS: ..........</span><br style="font-weight: bold;"><span style="font-weight: bold;">*COUNTRY: ..................</span><br style="font-weight: bold;"><span style="font-weight: bold;">*TEL: .....................</span><br style="font-weight: bold;"><span style="font-weight: bold;">*OCCUPATION: ..............</span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">Remember your obligation to secure an International Remittance Form as stated in United Nation act of (FRT209) that will help build and renew your transfer file for record keeping as a way of checkmating the present Economics crisis situations.</span><br style="font-weight: bold;"><span style="font-weight: bold;">Contact the\r\n below Electronic Transfer unit of WESTERN UNION for immediate programing of your first transfer:</span><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">Name: Rev.John Ntepe</span><br style="font-weight: bold;"><span style="font-weight: bold;">Mobile:+229 97292685</span><br style="font-weight: bold;"><span style="font-weight: bold;">Email: (western.union1891@live.fr) or (westerrnunion_2@sify.com)</span><br style="font-weight: bold;"><br style="font-weight: bold;"><span style="font-weight: bold;">&nbsp;</span><br style="font-weight: bold;"><span style="font-weight: bold;">Regards.</span><br style="font-weight: bold;"><span style="font-weight: bold;">Thanks and God Bless.</span><br style="font-weight: bold;"><span style="font-weight: bold;">Mrs.Cecil Edward</span><br style="font-weight: bold;"><br style="font-weight: bold;"></td></tr></table><br />-- \r\n<br />This message has been scanned for viruses and\r\n<br />dangerous content by\r\n<a href="http://www.mailscanner.info/"><b>MailScanner</b></a>, and is\r\n<br />believed to be clean.\r\n\r\n\r\n',
    headers={'return-path': ('<ceciledwards@sbcglobal.net>',), 'received': ('from murder ([unix socket])\r\n\t by i.aaa.net (Cyrus v2.2.12-Invoca-RPM-2.2.12-6.fc4) with LMTPA;\r\n\t Thu, 03 Dec 2009 10:50:45 -0800', 'from smtp.aaa.org (unknown [10.1.1.254])\r\n\tby i.aaa.net (Postfix) with ESMTP id B789577FFC\r\n\tfor <ccc@aaa.net>; Thu,  3 Dec 2009 10:50:44 -0800 (PST)', 'from imr-f9b5566049f9cb01.prolexic.com (unknown [10.2.2.254])\r\n\tby smtp.aaa.org (Postfix) with ESMTP id 6B026D64546\r\n\tfor <ccc@aaa.net>; Thu,  3 Dec 2009 12:08:32 -0800 (PST)', 'from web82107.mail.mud.yahoo.com (web82107.mail.mud.yahoo.com [209.191.84.220])\r\n\tby imr-f9b5566049f9cb01.prolexic.com (Postfix) with SMTP id 6B5392BA0459\r\n\tfor <ccc@aaa.net>; Thu,  3 Dec 2009 10:50:23 -0800 (PST)', '(qmail 85490 invoked by uid 60001); 3 Dec 2009 18:50:22 -0000', 'from [41.222.192.69] by web82107.mail.mud.yahoo.com via HTTP; Thu, 03 Dec 2009 10:50:22 PST'), 'x-sieve': ('CMU Sieve 2.2',), 'dkim-signature': ('v=1; a=rsa-sha256; c=relaxed/relaxed; d=sbcglobal.net; s=s1024; t=1259866222; bh=aBaCpZTcwSmyoRxhnNZNc5KV/Eb3zHvR3BG0svTu0C0=; h=Message-ID:X-YMail-OSG:Received:X-Mailer:Date:From:Reply-To:Subject:To:MIME-Version:Content-Type; b=cREZCCsrtGfOYR9ckj97DV792GZUX/4Hktzlm5+WBuxdD8Q4XpjRz7dZ1Rei9JOKH8gseoE6KqujBA7EulWGx/XPX5TlDxgO8c2Vk3ae/Qeh38bDJ8MZXRc3dU1w+IMykQyU+qfFKHjkS1sTE7qcmheL1JsTs+BAXtyyqJL+J+4=',), 'domainkey-signature': ('a=rsa-sha1; q=dns; c=nofws;\r\n  s=s1024; d=sbcglobal.net;\r\n  h=Message-ID:X-YMail-OSG:Received:X-Mailer:Date:From:Reply-To:Subject:To:MIME-Version:Content-Type;\r\n  b=nvmIZcXhl5ZMIwmDabz/TSUlgtHH5VdCGrTn1U6/zkGM1pZvwJgq/BMbY+5o+mwlMz78DrUT9TJwfx48JDz8j4swqWh1dlEfztr4S18hgoVt7RqeuIxGOfOEpa6jlzbgE04EQcKy9ePZsSgOv97IH1Oh8HU7MxPUj1KO9NaKsTA=;',), 'message-id': ('<203751.85280.qm@web82107.mail.mud.yahoo.com>',), 'x-ymail-osg': ('M3VWGGoVM1mRrN0VVqOo_OuQD_g7jcvHWnqhUlpmVpXhEVZvd0t2zfR8Zvl5BY34dERYPAO_SdtSjPrdGHXgu8LQ7s1z74yCasGWj5jLvgVb.l8helkzU2RuUVfjxzO5AxztzNz1gt0nMG0iY4LrYoHWj1fvC6iduhm_H7LRUzBa5MezeY8soTyY1i0ugmXCgsAYu3etOBvYfwqnNmJmRBBgrgu7LB5aXqiQFTWhxKirD7cQrygLK3QPv7r4utOXt2viJDLFBgITADv.ZMOV5HL7VexNpvTIgDDxfYhDLy8F.h8nTquqIYSUUv5eMZUSbEml.QvSrtj5tjuryeWcIFTL6bHTwDBKNq_0gcEZWWbF_g6XiTjcGPVNDlVXVzni3DMOlt8_cscWGy95q_y2ArbGRrJLO5.0OQPdi6uxNIN.qXGwlijACJTlnpd1_k._CkT5_ivRiof0WAcmszBifAA8PLImnre40_vLQfGQN3cN0QfyYgv_dgVaXBhwkeuBfnthQugsAUbBcifuS7ymi37vSSTYpJ.nuHinkBsm8fVBr3FXNGZXB.YtpcxSSbvhimTtoZviodhD7zG2a1oE.X0GUT6FmsnUwVZPZkw0n_17m9.SSe8Qok8YXc9xfTKJyQAtn2yoMrS5.zMMhoQ8h26dmiXyv2N7V5SjOBYCc7ynqi7H6yPWe7FHQls_arY8vzF8xiC1THpiXJkiN4JHScNPk8aVxwY8L278d3RwSdTKa6CjDw1eIxu9XanW.eB0x3t6_VmuNcDRjhTG022kURXkA6x.UuCrKdP0eiVnSXFI0KiI9Xzhg1AMoiMPZRYDQneEPkgtMw.PJePhfVrOo.svKrGzuk5dG6PDHIqTSmd8MwlhZ56eTsDrakeo3ooVoRW_4oi9vyc7LVaJ32shn5mD5RwNyKhPHvzCAVCc3tc_AwkNqoEehTKOaxWuZc_jVuVB4bjJZsXPGeDqh\r\n FuKqBNQHUzr8v6AeX3grpz3M_0jE2qPES2GbJEItyat4WrVzA4SerkByWZHS9xNj.j_xbqdnVznbAdftUA4GFjQMZZql1KgFqrOHnhNkp6Z1QO7IQjCDaVwTATJ5h5uEFbKdmr1QPmmFNbFQub.HwmfikVgWNBn90wUKS2CsJf2IEOHSOicDzIMoC6PWzjCXGGZHZMRcSmtaIXkZ4UYELtiQQCBRgZWh7mhV6wjjbxLE0xv5.lKPSsLzql8COylkhrnoVF2jckLWroGXHsFtEQ5qD2nhDmN.ZlJJ01c1BdE2rGCKbKNfh9qvqXYA0kt9TsfO.H_sp7NWKZmFVnVrGbszkg6xXs4Bo1ITBjxzITVenK_WwO_YPXUV2cHNAXFP88bhiRvKSS31GxaT12QR4RHrWqe0ZjkgfoO.jK9ysUx3NnVSmiDzmnENJAoYbO1Sf8JDVj5yDSCyMxvL4iI7xUBHIzq.lpr6yk1IRkE5074pxlITkHejyzljPbzIUF6OWg95Edlro_QjIQHGeEE1EzNE_JrscrjDYX6mW40CCLFu7ImZVuFmwxC11sC5MIj4KUp8TYSNj2n0WVcTt4jXzSOB4eOlRxtE9dDo3wACeEXc_dzD2BjIOpfUYnIUw2xgRN7wFpd4z6EQ2g3eEv6ny7x9sd0SEh36xG0ZC0juI7Qp0Rj6_1A_YBiIY0AODUdtV1vVuWLTq82Fj0xOhH7I5c03ZYRcJoQBpuc4GDnU.wCi3n.eb1_oHaocDz0E6b6UkpGBB.2d1SXx6BOVu1DEdm6KSg3BUeDld.GzUOUKtWbzyOYdPdedcTa4gljnujUb5tCkjpgEmz_iP0GCs7SYbTcj6AIQxAliexrcdQeNxqxS7hlNOwQmsSGyjufJ7Xrq_NnTp8cWCNUhgmtb4r_gcUjOnPJoz.YpZ8asjZ.uZOgHXpmPIsZL1gozfp_rqYzkx3NYJ8S47IMD84Fa3iVco5SWXVlUx\r\n pF_rRHgvkNQtdMaVU5YZdEGr6OlG.CTrAlZa0IoZ0HgFtB_Lg_',), 'x-mailer': ('YahooMailClassic/8.1.6 YahooMailWebService/0.8.100.260964',), 'date': ('Thu, 3 Dec 2009 10:50:22 -0800 (PST)',), 'from': ('Cecil Edwards <ceciledwards@sbcglobal.net>',), 'reply-to': ('western.uniontransfer1@hotmail.fr',), 'subject': ('Western Union Swift Money Transfer',), 'to': ('undisclosed recipients: ;',), 'mime-version': ('1.0',), 'content-type': ('multipart/alternative; boundary="0-2052022825-1259866222=:85280"',), 'x-csi-mailscanner-information': ('Please contact the ISP for more information',), 'x-csi-mailscanner': ('Found to be clean',), 'x-csi-mailscanner-spamcheck': ('spam, ORDB-RBL',), 'x-csi-mailscanner-from': ('ceciledwards@sbcglobal.net',), 'x-spam-status': ('Yes',)},
    attachments=[],
    from_values=EmailAddress(name='Cecil Edwards', email='ceciledwards@sbcglobal.net'),
    to_values=(),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(EmailAddress(name='', email='western.uniontransfer1@hotmail.fr'),),
)