import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Testing attachments',
    from_='jamis@37signals.com',
    to=('jamis@jamisbuck.org',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2007, 2, 22, 11, 20, 31, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=61200))),
    date_str='Thu, 22 Feb 2007 11:20:31 -0700',
    text='Here is a test of an attachment via email.\r\n\r\n- Jamis\r\n\r\n',
    html='',
    headers={'mime-version': ('1.0 (Apple Message framework v752.3)',), 'message-id': ('<2CCE0408-10C7-4045-9B16-A1C11C31469B@37signals.com>',), 'content-type': ('multipart/signed;\r\n\tmicalg=sha1;\r\n\tboundary=Apple-Mail-42-587703407;\r\n\tprotocol="application/pkcs7-signature"',), 'to': ('Jamis Buck <jamis@jamisbuck.org>',), 'subject': ('Testing attachments',), 'from': ('Jamis Buck <jamis@37signals.com>',), 'date': ('Thu, 22 Feb 2007 11:20:31 -0700',)},
    attachments=[
        dict(
            filename='truncated.png',
            content_id='',
            content_disposition='inline',
            content_type='image/png',
            payload=b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\xa5\x00\x00\x00\xd7\x08\x06\x00\x00\x00{\xc1\x91\x10\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\x08d\x88\x00\x00\x00\tpHYs\x00\x00\x0b\x12\x00\x00\x0b\x12\x01\xd2\xdd~\xfc\x00\x00\x00\x17tEXtCreation Time\x001/25/2007\x83\xf4"U\x00\x00\x00\x18tEXtSoftware\x00Adobe FireworksO\xb3\x1fN\x00\x002\x05iTXtXML:com.adobe.xmp<?xpacket begin="\xef\xbb\xbf" id="W5M0MpCehiHzreSzNTczkc9d"?>\n<x:xmpmeta xmlns:x="adobe:ns:meta/" x:xmptk="Adobe XMP Core 4.1-c020 1.255716, Tue Oct 10 2006 23:16:34">\n   <rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">\n      <rdf:Description rdf:about=""\n            xmlns:xap="http://ns.adobe.com/xap/1.0/">\n         <xap:CreatorTool>Adobe Fireworks CS3</xap:CreatorTool>\n         <xap:CreateDate>2007-01-25T05:28:21Z</xap:CreateDate>\n         <xap:ModifyDate>2007-01-25T05:28:21Z</xap:ModifyDate>\n      </rdf:Description>\n      <rdf:Description rdf:about=""\n            xmlns:dc="http://purl.org/dc/elements/1.1/">\n         <dc:format>image/png</dc:format>\n      </rdf:Descript\x86\x1a#\xa6i\xc91\xf6\x98\x16d\xa4]h9<`\xa6\x1duc\xfd\xcf@\xb7HR+lFu\xdf\x05\xdek\xa4\xd1Qco\x87\xf9Q\xed$\xb1\x0f*\x01\xca\xb4u\xe9Z^\x17[\x0e2\x8d\x9c_\xb7\x07{}\x90\xe6\xd9bi;\x01\x98\x16b\xa3\xbdjzQ\xdf\nL\xf6\xc49^\xc9A\xf5\xaf\xa4[$\xed5\xbd\x1f:k\x9d\xcca\xdf<PP\x0c\xa7\xac\xcb\'&\x0c\x12\xfb\x0b\x0e[^2\x04\xb9\xc8\xbeI#\xa6\xfc\xb6\'\\6n\xea+\x8f\x12?%`\x16\xfe9O1\xc7W\xfd\x9b\xe7\xb9\xae\x12b`\xaa\xa3\xa3\x9b\xc7~&i\xf9U$[\xdc\\Q\xf7z$sVs\x8e\xcf\x91\n\x9b\xf6\'\xb7H\xb1\x19\x07\xf6j\xc8\x0b,\x8a\xa5\x11c\xe1\xb7\xe6#\x8ceJ\xc7m\xab\x07\x9d\xbf4@\x03\xef\xf4Q\xed\x01\xb2H\xca\xba;n.[j-\x93\x10\x02\x9e\x9f\x9f\x8b$\xd5\xab\x82Vc\x9bu\x1bf\xfb{*\xbc\x80\xd8\x9e[\xe4\x9dcd_$/\xa1\xb3\xbcmY\xab\x1exc\\\xbb\'\xb9\xf6\xd3\x03\x0e\xb7\xd7\xeb\x1bk\x16\xbb\x01\x8f\xd3\xb9\r\xcf~\xf7\xda\xf7\xfam\xfb\xc0\xbc\xb9]}/\xbd~\xdb6z\xe5\xd8\xdf\xb0\xfeGoE\x19\x97e\x9e\x1c\xd5\xe14\xc5\x98\xf2]\xb8\x13\xf6E\xb3M\xb9\xae+N\xa7\x13B\xde\xd7\xcbR\x94\x07@\x07I\xd3\xf9\x01\x94\x18\xbcv`\xed`\xf5^\xf6\x1e0\xed@\xf4xY>\xa3\x17\xe4\xa5\xdb0\x1a\xe7\xd9\xe7\xf1\x9e\xcf\xde{mz\xef\x87\x9f\xc7>\x13\xa7\xf7\xea\xd8vz\xe3\xc7`a\xa0\xb5\x8buj\xd4\x86\xcd>\xad\xcf\xbc4\xcf{6=\x15\xa4HJ;\xe7\xcdj\x9d\x81\xc5\x8d\xf0B`\x8esj\xf9\x9e\xe4\xb4\xe9\xbd\x97c_\xb6\x1d\xbc\x11\x98\xb8lo\xf0{\x92p\xc4\xcf\x93\xaa^;\xfc?\xd7\xe9\xbd\xfc#\xcf\xd1\xcb\x1b\xf1<\x9a\xd7\xeb;\xd0n\x8d\xe1\xf6<\x89\xc7\xe0\xb4\x00\xb5\xf7\xdb\xb4\x04Lyyy\x89Z`$\xf9\xac\xf4\xdb\xfb\x9f\xeb\x02\xad\xba\xb7yJ#\x15\x7f\xa7\xcf!\xab\xaam\x9e\x07`\x0b:\x0f\x8c\x9a\xa7v"\xdfs\xfe\xb2\xe4\rxY\xe0\xc5\x18\xd3\xdc\xb7\x88\x94\xb0\x90U\xd9\xb63,E{\x9b\xcd\xec\xe9\x1az\xddS\xe1\x1c\xa0\xbf\x83\xf2\xf3iOj{\x12Q\xaf\x9e\xb4\xe3rV\x8az\x80\xb5\xf6j\xb1)\xb5\xb2:3\x9e\xd8e\xe7\x87m\n\xab\xfe\xb8\xbe\'!\x8f\xa8ak\x9c\xdf\xe9\xc7\x90g\xe7\xf1\xbd\x07B\x9b\xce`\xb4\x00e@\xda\x9d\xb2l\xde4!!6D\x81\xd6\xabd\xaf\x9c;\xac\x92\x94\xbdw\xae\xeby\x9cV\x8d\xdb{;\xbbt\xa7\xcf\xa7\x91=9\x02\xa1\xcd\xbfV\x9ds\x1d\xf6U\x16\x96|\xecX\x8cT\xb5u\x8a\xac\x8a\xe6\xb9s~8\xb6\x1b8\xdf\x0e\xca\x1d\x94?\x96z\x8eT\x0f\x88z?\x02\xaa\xcd\x03* =-\xabec\x8cUR2\x98\xacd\xb4@\xb3\xbb\x1e=\x90Y\x00r>\x80\x86\xa7\x07\xc2;0?\x9fz`\x1cy\xe5\x1e\xd8\xacZ\xe64\xbd\xe7I\x19\xd6\x9e^4G^__\xa3\x16d\xa9g\xedDu`\xac\r\xc9\xde4\xf3`Psp\xdd\xa6)\x9f;\xfd<d\xd7\xd2\xea=\xe0KM\xf6\xaa\xb5\xac\xe7q{y\x1c\xef\xd4\xfc\xbaG\x87$\x9f\x05\x9f\x17\xa3\xea\xa9r\x95\xb2\xcb\xb24\x0b;.\x97\xcbf\xb5\x91\xe7\xec\xfc\xdf\xa73\xbf\x92\xec\x81\xb9\xfcNXs\xb1t\xd3zV\x12\xb2\xe3l}\x0e\xe5\xc1\x9av#)\xb5 \x7f\r\x9eT\xe42=\xc9\xe890V22?%\x0b\xf6;\xfdx\xea9\x99Vrz`\xf5\xa4\x1f_=\x87F\xaf\x96\x9f\x9cN\xa7\xa8\r\xf2\xd5\xaa\xf1\x1e8{j_\xcb2\xd8za \xa6\xbb-\xf9u\xe4\xd9\x98\xf6\x9dy[\xb0m9\x06\x9a\xe7u3/\x0bt\x11iw3\xb2\x18U\xb0y\xcc\x81\xf6\'\xf3F6\x83\x92n\xad\xe0:\xc0\x16\xac=\xe3\xfb.A?\x8e\xf6L$\x06\x9f\xfe\x0f\xd4\xd9\x17\xa5\x1e\xc8\xac\xbd\xa9\xf9\x16\xac\x1e \x01\xe0?\x07;/\xaf\x06\xc6\xf5C\x00\x00\x00\x00IEND\xaeB`\x82',
        ),
        
        dict(
            filename='smime.p7s',
            content_id='',
            content_disposition='attachment',
            content_type='application/pkcs7-signature',
            payload=b'0\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x02\xa0\x800\x80\x02\x01\x011\x0b0\t\x06\x05+\x0e\x03\x02\x1a\x05\x000\x80\x06\t*\x86H\x86\xf7\r\x01\x07\x01\x00\x00\xa0\x82\x06\'0\x82\x02\xe00\x82\x02I\xa0\x03\x02\x01\x02\x02\x10X\xe7\x14\xd6\x17\xc01\x19Ef9\x12G\xf3\xa2\x950\r\x06\t*\x86H\x86\xf7\r\x01\x01\x05\x05\x000b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA0\x1e\x17\r060912170112Z\x17\r070912170112Z0E1\x1f0\x1d\x06\x03U\x04\x03\x13\x16Thawte Freemail Member1"0 \x06\t*\x86H\x86\xf7\r\x01\t\x01\x16\x13jamis@37signals.com0\x82\x01"0\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x03\x82\x01\x0f\x000\x82\x01\n\x02\x82\x01\x01\x00\xed\x80\xf4\x97\x8e\x14\x81I\x1b\xac\xfc\xa57\x00\x95\xda\xd9\xdas\x1e\xf9v\xf5\xb4\xda\xdb\x1e\n\x15\xcc\xdf\xd0\x84u\xcc\xe2\xab-\xd8\xc9}\xdd\xc9\x85.3&\xc0n\xcf\xf5\x12^S\x8a\r\xc7\xe8\xd3\xa9Z\x01\x07\xb3U5\xed\x7f\xa3\x9e\x83\xa3B\xa1|\xc6}\x89@\xd0t\xf2\xdb\x91\x93*\xe0A)\x14\xc7f\xe8\xfc\x8c\xdek\x91+\x03\xe1\x8f\xae\xa2\x01g\xbf\xa2\xc0\x9b\xf0:0P\xad\x9f\xeb\xab\xdaG\x1d\x19cC\x10\x1c\x82+\\M6M\xae\x08|\x08H|\xfa\x81.FxZ\x04\xd8\x04s}\xbc\xc7Xy\xadc\x17A\x8e\xe2\n\x86\x93\\*\xc1\xbd\xf2\xc6\xfd\x901\x83\x1b\xc0\x9e\x92#\xe9?f9\x12G\xf3\xa2\x950\x81\x87\x06\x0b*\x86H\x86\xf7\r\x01\t\x10\x02\x0b1x\xa0v0b1\x0b0\t\x06\x03U\x04\x06\x13\x02ZA1%0#\x06\x03U\x04\n\x13\x1cThawte Consulting (Pty) Ltd.1,0*\x06\x03U\x04\x03\x13#Thawte Personal Freemail Issuing CA\x02\x10X\xe7\x14\xd6\x17\xc01\x19Ef9\x12G\xf3\xa2\x950\r\x06\t*\x86H\x86\xf7\r\x01\x01\x01\x05\x00\x04\x82\x01\x00\x9f\xc1\x08\x82\xde\xfe\xbf\xcaW\x91\x0ck\xf7l\x9e\'A\x84>sy\xb3\xdf\xe9\xa7\xddx\xba\xb9M\xf9\x9fzb\xc3\x16Yid]\x98\xbc\xa2\\\xfb\xd4\xf9\x04^\x1e\x94\x9f\xde]\xaa\xb0FL\xde\xc7D\xd1q}y\x1b\xa5\xff\xe4\x13\x14\x97\x035s\x84\x03\x11\xb5\xcc-\x86\xa7?\xbas\xa4k_\x83\xae\xd7c\xf0\x92\x9f\xa96\xb6VM&?\x99\x98\x1d\xa9\xc0+\xba\x93\x81q\x98\xbb\xa8\x18\xe8Y\xcc\xb9\xc1\xbexu\xfb\xd2J:\xe3\x9a\xa2\xdb\x90\x7f\xc4\xf3\x0c?\xea\x01\x90\xb9O\xf1^\x90\x14f\x05+Nd\x07\xac\xd2\x9e!\xd4\xa1\xe6\x80\xe4;\x11Z\x15k\xe7\x99\xbf\x19\xffh\xb1*\xa5\xbfS\x1e\x96\xa9\xa9\xb2\xbc\x1bS\xb3\xfeX\x04Kg\xa5\x93\xa4\xfa\xe5h\xb1\xc6\x04P\x18T\xf85I\xd8\xe4\xafM\xd5\xd2\x8a\xf3-\x05\xd5\xe6\x19;\x06\xdbi>?SFPx\xbf\x03\xb7\xaf\xc4\xf6\x8e\xd2\xe98W\xccr\x8c\xd9M\xe0s\xee\x1a\x99+\x95|\x0f\x00\x00\x00\x00\x00\x00',
        ),
        ],
    from_values=EmailAddress(name='Jamis Buck', email='jamis@37signals.com'),
    to_values=(EmailAddress(name='Jamis Buck', email='jamis@jamisbuck.org'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)