import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='eml attachments ',
    from_='kaukinvk@yandex.ru',
    to=('imap.tools@ya.ru',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2019, 5, 1, 12, 20, 29, tzinfo=datetime.timezone(datetime.timedelta(seconds=18000))),
    date_str='Wed, 01 May 2019 12:20:29 +0500',
    text='UmVjZWl2ZWQ6IGZyb20gbXhmcm9udDJnLm1haWwueWFuZGV4Lm5ldCAoWzEyNy4wLjAuMV0pDQoJ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\r\nYjNmYmE0MGNjZDk2MDMwODRiZS0tDQo=UmVjZWl2ZWQ6IGZyb20gbXhmcm9udDJnLm1haWwueWFuZGV4Lm5ldCAoWzEyNy4wLjAuMV0pDQoJ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\r\nYjNmYmE0MGNjZDk2MDMwODRiZS0tDQo=',
    html='<div>two attach</div>',
    headers={'received': ('from mxback2g.mail.yandex.net ([127.0.0.1])\r\n\tby mxback2g.mail.yandex.net with LMTP id GCaAmtYs;\r\n\tWed, 1 May 2019 10:20:30 +0300', 'from mxback2g.mail.yandex.net (localhost.localdomain [127.0.0.1])\r\n\tby mxback2g.mail.yandex.net (Yandex) with ESMTP id C4C9426E11B7;\r\n\tWed,  1 May 2019 10:20:30 +0300 (MSK)', 'from localhost (localhost [::1])\r\n\tby mxback2g.mail.yandex.net (nwsmtp/Yandex) with ESMTP id HIJe2M7myP-KThSAlHL;\r\n\tWed, 01 May 2019 10:20:29 +0300', 'by myt5-262fb1897c00.qloud-c.yandex.net with HTTP;\r\n\tWed, 01 May 2019 10:20:29 +0300'), 'x-yandex-internal': ('1',), 'x-yandex-front': ('mxback2g.mail.yandex.net',), 'x-yandex-timemark': ('1556695229.976',), 'dkim-signature': ('v=1; a=rsa-sha256; c=relaxed/relaxed; d=yandex.ru; s=mail; t=1556695230;\r\n\tbh=Zmx9VIRnyRQRflnyRn1kpGYLdyO5YBC6/Wu9orXmTDk=;\r\n\th=Message-Id:Date:Subject:To:From;\r\n\tb=AM6LCew9Mz4XSIF78liQrYp4Kyg9RonJDizzaCNBRs5bOwla7bFphFQMIIYfmneJw\r\n\t 51WhDeo5L9ahRqG27no2kwmOggZ+Do99qY8oReCFObnfnaII6V2ZIvogKFXEfjHTB0\r\n\t bZlslZahe65zi1+xD7PnpeSWv8aYLZBgPuNJgA10=',), 'authentication-results': ('mxback2g.mail.yandex.net; dkim=pass header.i=@yandex.ru',), 'x-yandex-spam': ('1',), 'x-yandex-sender-uid': ('52494202',), 'from': ('=?utf-8?B?0JrQsNGD0LrQuNC9INCS0LvQsNC00LjQvNC40YA=?= <kaukinvk@yandex.ru>',), 'envelope-from': ('kaukinvk@yandex.ru',), 'to': ('imap.tools@ya.ru',), 'subject': ('eml attachments ',), 'mime-version': ('1.0',), 'x-mailer': ('Yamail [ http://yandex.ru ] 5.0',), 'date': ('Wed, 01 May 2019 12:20:29 +0500',), 'message-id': ('<8872861556695229@myt5-262fb1897c00.qloud-c.yandex.net>',), 'content-type': ('multipart/mixed;\r\n\tboundary="----==--bound.887287.myt5-262fb1897c00.qloud-c.yandex.net"',), 'return-path': ('kaukinvk@yandex.ru',), 'x-yandex-forward': ('d910e166fb8fe03380632bd988c8b67f',)},
    attachments=[
        dict(
            filename='yandex_email.eml',
            content_id='',
            content_disposition='attachment',
            content_type='message/rfc822',
            payload=b'Received: from mxfront2g.mail.yandex.net ([127.0.0.1])\r\n\tby mxfront2g.mail.yandex.net with LMTP id SONmnPb1\r\n\tfor <KaukinVK@yandex.ru>; Sun, 28 Apr 2019 14:32:37 +0300\r\nReceived: from out-3.smtp.github.com (out-3.smtp.github.com [192.30.252.194])\r\n\tby mxfront2g.mail.yandex.net (nwsmtp/Yandex) with ESMTPS id IxG07LRtjb-Warm4eXW;\r\n\tSun, 28 Apr 2019 14:32:36 +0300\r\n\t(using TLSv1.2 with cipher ECDHE-RSA-AES128-GCM-SHA256 (128/128 bits))\r\n\t(Client certificate not present)\r\nReturn-Path: noreply@github.com\r\nX-Yandex-Front: mxfront2g.mail.yandex.net\r\nX-Yandex-TimeMark: 1556451156.153\r\nAuthentication-Results: mxfront2g.mail.yandex.net; spf=pass (mxfront2g.mail.yandex.net: domain of github.com designates 192.30.252.194 as permitted sender, rule=[ip4:192.30.252.0/22]) smtp.mail=noreply@github.com; dkim=pass header.i=@github.com\r\nX-Yandex-Spam: 2\r\nX-Yandex-Fwd: OTM4OTM4Mjc2OTU3NTU3NTYyMyw5NzM5MTE2MTc5NzI0MTAxOTMw\r\nDate: Sun, 28 Apr 2019 04:32:35 -0700\r\nDKIM-Signature: v=1; a=rsa-sha256; c=relaxed/relaxed; d=github.com;\r\n\ts=pf2014; t=1556451155;\r\n\tbh=FsRPUKn3beupt2P3QB36UzfVESVClL07TVINnTX0nBg=;\r\n\th=Date:From:Reply-To:To:Cc:Subject:List-ID:List-Archive:List-Post:\r\n\t List-Unsubscribe:From;\r\n\tb=bzfQrv25o0IpZKiIrcGgLzDvM2VLfYficzjqSPPT0Rd3u3D66awwlxaVEHWqpE6dc\r\n\t 8ETR0+A3kN1V3xlo9Etlgn31105g3OQFG0jBMTdymdaXA/hu8Hrjr4Wf1krAGquHpq\r\n\t gJoF4ChuMuUhL554hguAmsWZ1BmzcjH6vVSa0ZEU=\r\nFrom: Buddy Rikard <notifications@github.com>\r\nReply-To: ikvk/imap_tools <reply+AAV6N2Z5ZMVYPVVMJBXEZE522LA5HEVBNHHBUHAPJU@reply.github.com>\r\nTo: ikvk/imap_tools <imap_tools@noreply.github.com>\r\nCc: Subscribed <subscribed@noreply.github.com>\r\nMessage-ID: <ikvk/imap_tools/issues/4@github.com>\r\nSubject: [ikvk/imap_tools] does not extract attached EML files (#4)\r\nMime-Version: 1.0\r\nContent-Type: multipart/alternative;\r\n boundary="--==_mimepart_5cc58f537542_49eb3fba40ccd9603084be";\r\n charset=UTF-8\r\nContent-Transfer-Encoding: 7bit\r\nPrecedence: list\r\nX-GitHub-Sender: TpyoKnig\r\nX-GitHub-Recipient: ikvk\r\nX-GitHub-Reason: subscribed\r\nList-ID: ikvk/imap_tools <imap_tools.ikvk.github.com>\r\nList-Archive: https://github.com/ikvk/imap_tools\r\nList-Post: <mailto:reply+AAV6N2Z5ZMVYPVVMJBXEZE522LA5HEVBNHHBUHAPJU@reply.github.com>\r\nList-Unsubscribe: <mailto:unsub+AAV6N2Z5ZMVYPVVMJBXEZE522LA5HEVBNHHBUHAPJU@reply.github.com>,\r\n <https://github.com/notifications/unsubscribe/AAV6N24RJYGGQBI5PKMGTK3PSWDNHANCNFSM4HI6JQUA>\r\nX-Auto-Response-Suppress: All\r\nX-GitHub-Recipient-Address: KaukinVK@yandex.ru\r\nX-Yandex-Forward: efb42d76edf7d5556112f3dac099406e\r\n\r\n\r\n----==_mimepart_5cc58f537542_49eb3fba40ccd9603084be\r\nContent-Type: text/plain;\r\n charset=UTF-8\r\nContent-Transfer-Encoding: 7bit\r\n\r\nAs .EML files have these headers:\r\n\r\n`--00000000000094809105878daac0\r\nContent-Type: message/rfc822; name="Totally legit email (2).eml"\r\nContent-Disposition: attachment; filename="Totally legit email (2).eml"\r\nContent-Transfer-Encoding: base64\r\nContent-ID: <f_jv0apprb0>\r\nX-Attachment-Id: f_jv0apprb0\r\n\r\nMIME-Version: 1.0\r\nDate: Fri, 25 Jan 2019 10:37:47 -0800\r\nMessage-ID: <CAKKXz3O5qFoTi68Ls4QCqZzQK8m6mASymTZ9ib6ysnBTOwwJOg@mail.gmail.com>\r\nSubject: Totally legit email\r\nFrom: REDACTED <REDACTED@DOMAIN.COM>\r\nTo: REDACTED <REDACTED@DOMAIN.COM>\r\nContent-Type: multipart/alternative; boundary="000000000000a30bb605804c9ff2"\r\n\r\n--000000000000a30bb605804c9ff2\r\nContent-Type: text/plain; charset="UTF-8"\r\nContent-Transfer-Encoding: quoted-printable`\r\n\r\nimap-tools does not return this as an attachment and completely disregards the attachment itself along with the filename. \r\n\r\n-- \r\nYou are receiving this because you are subscribed to this thread.\r\nReply to this email directly or view it on GitHub:\r\nhttps://github.com/ikvk/imap_tools/issues/4\r\n----==_mimepart_5cc58f537542_49eb3fba40ccd9603084be\r\nContent-Type: text/html;\r\n charset=UTF-8\r\nContent-Transfer-Encoding: 7bit\r\n\r\n<p>As .EML files have these headers:</p>\r\n<p>`--00000000000094809105878daac0<br>\r\nContent-Type: message/rfc822; name="Totally legit email (2).eml"<br>\r\nContent-Disposition: attachment; filename="Totally legit email (2).eml"<br>\r\nContent-Transfer-Encoding: base64<br>\r\nContent-ID: &lt;f_jv0apprb0&gt;<br>\r\nX-Attachment-Id: f_jv0apprb0</p>\r\n<p>MIME-Version: 1.0<br>\r\nDate: Fri, 25 Jan 2019 10:37:47 -0800<br>\r\nMessage-ID: <a href="mailto:CAKKXz3O5qFoTi68Ls4QCqZzQK8m6mASymTZ9ib6ysnBTOwwJOg@mail.gmail.com">CAKKXz3O5qFoTi68Ls4QCqZzQK8m6mASymTZ9ib6ysnBTOwwJOg@mail.gmail.com</a><br>\r\nSubject: Totally legit email<br>\r\nFrom: REDACTED <a href="mailto:REDACTED@DOMAIN.COM">REDACTED@DOMAIN.COM</a><br>\r\nTo: REDACTED <a href="mailto:REDACTED@DOMAIN.COM">REDACTED@DOMAIN.COM</a><br>\r\nContent-Type: multipart/alternative; boundary="000000000000a30bb605804c9ff2"</p>\r\n<p>--000000000000a30bb605804c9ff2<br>\r\nContent-Type: text/plain; charset="UTF-8"<br>\r\nContent-Transfer-Encoding: quoted-printable`</p>\r\n<p>imap-tools does not return this as an attachment and completely disregards the attachment itself along with the filename.</p>\r\n\r\n<p style="font-size:small;-webkit-text-size-adjust:none;color:#666;">&mdash;<br />You are receiving this because you are subscribed to this thread.<br />Reply to this email directly, <a href="https://github.com/ikvk/imap_tools/issues/4">view it on GitHub</a>, or <a href="https://github.com/notifications/unsubscribe-auth/AAV6N2ZD2P5MW33322GDAFTPSWDNHANCNFSM4HI6JQUA">mute the thread</a>.<img src="https://github.com/notifications/beacon/AAV6N27JEB4SBCE3VILPO6LPSWDNHANCNFSM4HI6JQUA.gif" height="1" width="1" alt="" /></p>\r\n<script type="application/json" data-scope="inboxmarkup">{"api_version":"1.0","publisher":{"api_key":"05dde50f1d1a384dd78767c55493e4bb","name":"GitHub"},"entity":{"external_key":"github/ikvk/imap_tools","title":"ikvk/imap_tools","subtitle":"GitHub repository","main_image_url":"https://github.githubassets.com/images/email/message_cards/header.png","avatar_image_url":"https://github.githubassets.com/images/email/message_cards/avatar.png","action":{"name":"Open in GitHub","url":"https://github.com/ikvk/imap_tools"}},"updates":{"snippets":[{"icon":"DESCRIPTION","message":"does not extract attached EML files (#4)"}],"action":{"name":"View Issue","url":"https://github.com/ikvk/imap_tools/issues/4"}}}</script>\r\n<script type="application/ld+json">[\r\n{\r\n"@context": "http://schema.org",\r\n"@type": "EmailMessage",\r\n"potentialAction": {\r\n"@type": "ViewAction",\r\n"target": "https://github.com/ikvk/imap_tools/issues/4",\r\n"url": "https://github.com/ikvk/imap_tools/issues/4",\r\n"name": "View Issue"\r\n},\r\n"description": "View this Issue on GitHub",\r\n"publisher": {\r\n"@type": "Organization",\r\n"name": "GitHub",\r\n"url": "https://github.com"\r\n}\r\n}\r\n]</script>\r\n----==_mimepart_5cc58f537542_49eb3fba40ccd9603084be--\r\n',
        ),
        
        dict(
            filename='yandex_email.eml',
            content_id='',
            content_disposition='attachment',
            content_type='message/rfc822',
            payload=b'Received: from mxfront2g.mail.yandex.net ([127.0.0.1])\r\n\tby mxfront2g.mail.yandex.net with LMTP id SONmnPb1\r\n\tfor <KaukinVK@yandex.ru>; Sun, 28 Apr 2019 14:32:37 +0300\r\nReceived: from out-3.smtp.github.com (out-3.smtp.github.com [192.30.252.194])\r\n\tby mxfront2g.mail.yandex.net (nwsmtp/Yandex) with ESMTPS id IxG07LRtjb-Warm4eXW;\r\n\tSun, 28 Apr 2019 14:32:36 +0300\r\n\t(using TLSv1.2 with cipher ECDHE-RSA-AES128-GCM-SHA256 (128/128 bits))\r\n\t(Client certificate not present)\r\nReturn-Path: noreply@github.com\r\nX-Yandex-Front: mxfront2g.mail.yandex.net\r\nX-Yandex-TimeMark: 1556451156.153\r\nAuthentication-Results: mxfront2g.mail.yandex.net; spf=pass (mxfront2g.mail.yandex.net: domain of github.com designates 192.30.252.194 as permitted sender, rule=[ip4:192.30.252.0/22]) smtp.mail=noreply@github.com; dkim=pass header.i=@github.com\r\nX-Yandex-Spam: 2\r\nX-Yandex-Fwd: OTM4OTM4Mjc2OTU3NTU3NTYyMyw5NzM5MTE2MTc5NzI0MTAxOTMw\r\nDate: Sun, 28 Apr 2019 04:32:35 -0700\r\nDKIM-Signature: v=1; a=rsa-sha256; c=relaxed/relaxed; d=github.com;\r\n\ts=pf2014; t=1556451155;\r\n\tbh=FsRPUKn3beupt2P3QB36UzfVESVClL07TVINnTX0nBg=;\r\n\th=Date:From:Reply-To:To:Cc:Subject:List-ID:List-Archive:List-Post:\r\n\t List-Unsubscribe:From;\r\n\tb=bzfQrv25o0IpZKiIrcGgLzDvM2VLfYficzjqSPPT0Rd3u3D66awwlxaVEHWqpE6dc\r\n\t 8ETR0+A3kN1V3xlo9Etlgn31105g3OQFG0jBMTdymdaXA/hu8Hrjr4Wf1krAGquHpq\r\n\t gJoF4ChuMuUhL554hguAmsWZ1BmzcjH6vVSa0ZEU=\r\nFrom: Buddy Rikard <notifications@github.com>\r\nReply-To: ikvk/imap_tools <reply+AAV6N2Z5ZMVYPVVMJBXEZE522LA5HEVBNHHBUHAPJU@reply.github.com>\r\nTo: ikvk/imap_tools <imap_tools@noreply.github.com>\r\nCc: Subscribed <subscribed@noreply.github.com>\r\nMessage-ID: <ikvk/imap_tools/issues/4@github.com>\r\nSubject: [ikvk/imap_tools] does not extract attached EML files (#4)\r\nMime-Version: 1.0\r\nContent-Type: multipart/alternative;\r\n boundary="--==_mimepart_5cc58f537542_49eb3fba40ccd9603084be";\r\n charset=UTF-8\r\nContent-Transfer-Encoding: 7bit\r\nPrecedence: list\r\nX-GitHub-Sender: TpyoKnig\r\nX-GitHub-Recipient: ikvk\r\nX-GitHub-Reason: subscribed\r\nList-ID: ikvk/imap_tools <imap_tools.ikvk.github.com>\r\nList-Archive: https://github.com/ikvk/imap_tools\r\nList-Post: <mailto:reply+AAV6N2Z5ZMVYPVVMJBXEZE522LA5HEVBNHHBUHAPJU@reply.github.com>\r\nList-Unsubscribe: <mailto:unsub+AAV6N2Z5ZMVYPVVMJBXEZE522LA5HEVBNHHBUHAPJU@reply.github.com>,\r\n <https://github.com/notifications/unsubscribe/AAV6N24RJYGGQBI5PKMGTK3PSWDNHANCNFSM4HI6JQUA>\r\nX-Auto-Response-Suppress: All\r\nX-GitHub-Recipient-Address: KaukinVK@yandex.ru\r\nX-Yandex-Forward: efb42d76edf7d5556112f3dac099406e\r\n\r\n\r\n----==_mimepart_5cc58f537542_49eb3fba40ccd9603084be\r\nContent-Type: text/plain;\r\n charset=UTF-8\r\nContent-Transfer-Encoding: 7bit\r\n\r\nAs .EML files have these headers:\r\n\r\n`--00000000000094809105878daac0\r\nContent-Type: message/rfc822; name="Totally legit email (2).eml"\r\nContent-Disposition: attachment; filename="Totally legit email (2).eml"\r\nContent-Transfer-Encoding: base64\r\nContent-ID: <f_jv0apprb0>\r\nX-Attachment-Id: f_jv0apprb0\r\n\r\nMIME-Version: 1.0\r\nDate: Fri, 25 Jan 2019 10:37:47 -0800\r\nMessage-ID: <CAKKXz3O5qFoTi68Ls4QCqZzQK8m6mASymTZ9ib6ysnBTOwwJOg@mail.gmail.com>\r\nSubject: Totally legit email\r\nFrom: REDACTED <REDACTED@DOMAIN.COM>\r\nTo: REDACTED <REDACTED@DOMAIN.COM>\r\nContent-Type: multipart/alternative; boundary="000000000000a30bb605804c9ff2"\r\n\r\n--000000000000a30bb605804c9ff2\r\nContent-Type: text/plain; charset="UTF-8"\r\nContent-Transfer-Encoding: quoted-printable`\r\n\r\nimap-tools does not return this as an attachment and completely disregards the attachment itself along with the filename. \r\n\r\n-- \r\nYou are receiving this because you are subscribed to this thread.\r\nReply to this email directly or view it on GitHub:\r\nhttps://github.com/ikvk/imap_tools/issues/4\r\n----==_mimepart_5cc58f537542_49eb3fba40ccd9603084be\r\nContent-Type: text/html;\r\n charset=UTF-8\r\nContent-Transfer-Encoding: 7bit\r\n\r\n<p>As .EML files have these headers:</p>\r\n<p>`--00000000000094809105878daac0<br>\r\nContent-Type: message/rfc822; name="Totally legit email (2).eml"<br>\r\nContent-Disposition: attachment; filename="Totally legit email (2).eml"<br>\r\nContent-Transfer-Encoding: base64<br>\r\nContent-ID: &lt;f_jv0apprb0&gt;<br>\r\nX-Attachment-Id: f_jv0apprb0</p>\r\n<p>MIME-Version: 1.0<br>\r\nDate: Fri, 25 Jan 2019 10:37:47 -0800<br>\r\nMessage-ID: <a href="mailto:CAKKXz3O5qFoTi68Ls4QCqZzQK8m6mASymTZ9ib6ysnBTOwwJOg@mail.gmail.com">CAKKXz3O5qFoTi68Ls4QCqZzQK8m6mASymTZ9ib6ysnBTOwwJOg@mail.gmail.com</a><br>\r\nSubject: Totally legit email<br>\r\nFrom: REDACTED <a href="mailto:REDACTED@DOMAIN.COM">REDACTED@DOMAIN.COM</a><br>\r\nTo: REDACTED <a href="mailto:REDACTED@DOMAIN.COM">REDACTED@DOMAIN.COM</a><br>\r\nContent-Type: multipart/alternative; boundary="000000000000a30bb605804c9ff2"</p>\r\n<p>--000000000000a30bb605804c9ff2<br>\r\nContent-Type: text/plain; charset="UTF-8"<br>\r\nContent-Transfer-Encoding: quoted-printable`</p>\r\n<p>imap-tools does not return this as an attachment and completely disregards the attachment itself along with the filename.</p>\r\n\r\n<p style="font-size:small;-webkit-text-size-adjust:none;color:#666;">&mdash;<br />You are receiving this because you are subscribed to this thread.<br />Reply to this email directly, <a href="https://github.com/ikvk/imap_tools/issues/4">view it on GitHub</a>, or <a href="https://github.com/notifications/unsubscribe-auth/AAV6N2ZD2P5MW33322GDAFTPSWDNHANCNFSM4HI6JQUA">mute the thread</a>.<img src="https://github.com/notifications/beacon/AAV6N27JEB4SBCE3VILPO6LPSWDNHANCNFSM4HI6JQUA.gif" height="1" width="1" alt="" /></p>\r\n<script type="application/json" data-scope="inboxmarkup">{"api_version":"1.0","publisher":{"api_key":"05dde50f1d1a384dd78767c55493e4bb","name":"GitHub"},"entity":{"external_key":"github/ikvk/imap_tools","title":"ikvk/imap_tools","subtitle":"GitHub repository","main_image_url":"https://github.githubassets.com/images/email/message_cards/header.png","avatar_image_url":"https://github.githubassets.com/images/email/message_cards/avatar.png","action":{"name":"Open in GitHub","url":"https://github.com/ikvk/imap_tools"}},"updates":{"snippets":[{"icon":"DESCRIPTION","message":"does not extract attached EML files (#4)"}],"action":{"name":"View Issue","url":"https://github.com/ikvk/imap_tools/issues/4"}}}</script>\r\n<script type="application/ld+json">[\r\n{\r\n"@context": "http://schema.org",\r\n"@type": "EmailMessage",\r\n"potentialAction": {\r\n"@type": "ViewAction",\r\n"target": "https://github.com/ikvk/imap_tools/issues/4",\r\n"url": "https://github.com/ikvk/imap_tools/issues/4",\r\n"name": "View Issue"\r\n},\r\n"description": "View this Issue on GitHub",\r\n"publisher": {\r\n"@type": "Organization",\r\n"name": "GitHub",\r\n"url": "https://github.com"\r\n}\r\n}\r\n]</script>\r\n----==_mimepart_5cc58f537542_49eb3fba40ccd9603084be--\r\n',
        ),
        ],
    from_values=EmailAddress(name='Каукин Владимир', email='kaukinvk@yandex.ru'),
    to_values=(EmailAddress(name='', email='imap.tools@ya.ru'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)