import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Returned mail: see transcript for details',
    from_='MAILER-DAEMON@tttttt.com.au',
    to=('mikel@sssss.net',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2007, 12, 24, 10, 3, 53, tzinfo=datetime.timezone(datetime.timedelta(seconds=39600))),
    date_str='Mon, 24 Dec 2007 10:03:53 +1100',
    text='The original message was received at Mon, 24 Dec 2007 10:03:47 +1100\r\nfrom 60-0-0-146.static.tttttt.com.au [60.0.0.146]\r\n\r\nThis message was generated by mail12.tttttt.com.au\r\n\r\n   ----- The following addresses had permanent fatal errors -----\r\n<edwin@zzzzzzz.com>\r\n    (reason: 553 5.3.0 <edwin@zzzzzzz.com>... Unknown E-Mail Address)\r\n\r\n   ----- Transcript of session follows -----\r\n... while talking to mail.zzzzzz.com.:\r\n>>> DATA\r\n<<< 553 5.3.0 <edwin@zzzzzzz.com>... Unknown E-Mail Address\r\n550 5.1.1 <edwin@zzzzzzz.com>... User unknown\r\n<<< 503 5.0.0 Need RCPT (recipient)\r\n\r\n-- \r\nThis message has been scanned for viruses and\r\ndangerous content by MailScanner, and is\r\nbelieved to be clean.\r\n\r\n',
    html='',
    headers={'return-path': ('<MAILER-DAEMON@imap01.sssss.net>',), 'received': ('from acomputer ([unix socket])\r\n\t by imap01.sssss.net (Cyrus) with LMTPA;\r\n\t Sun, 23 Dec 2007 15:04:04 -0800', 'from smtp.sssss.org (unknown [198.0.0.92])\r\n\tby imap01.sssss.net (Postfix) with ESMTP id E434877FB0\r\n\tfor <mikel@sssss.net>; Sun, 23 Dec 2007 15:04:03 -0800 (PST)', 'from mail12.tttttt.com.au (mail12.tttttt.com.au [203.0.0.162])\r\n\tby smtp.sssss.org (Postfix) with ESMTP id 53313B42B7\r\n\tfor <mikel@sssss.net>; Sun, 23 Dec 2007 15:03:54 -0800 (PST)', 'from localhost (localhost)\r\n\tby mail12.tttttt.com.au (envelope-from MAILER-DAEMON) (8.14.2/8.14.2) id lBNN3rDp003436;\r\n\tMon, 24 Dec 2007 10:03:53 +1100'), 'x-sieve': ('CMU Sieve 2.2',), 'date': ('Mon, 24 Dec 2007 10:03:53 +1100',), 'from': ('Mail Delivery Subsystem <MAILER-DAEMON@tttttt.com.au>',), 'message-id': ('<200712232303.lBNN3rDp003436@mail12.rrrr.com.au>',), 'to': ('<mikel@sssss.net>',), 'mime-version': ('1.0',), 'content-type': ('multipart/report; report-type=delivery-status;\r\n\tboundary="lBNN3rDp003436.1198451033/mail12.rrrr.com.au"',), 'subject': ('Returned mail: see transcript for details',), 'auto-submitted': ('auto-generated (failure)',), 'x-spam-status': ('No',)},
    attachments=[],
    from_values=EmailAddress(name='Mail Delivery Subsystem', email='MAILER-DAEMON@tttttt.com.au'),
    to_values=(EmailAddress(name='', email='mikel@sssss.net'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)