import datetime
from imap_tools import EmailAddress

DATA = dict(
    subject='Low or High Blood Pressure? We can help.',
    from_='fyouizjnp@swissonline.ch',
    to=('bait-passover@em.ca',),
    cc=(),
    bcc=(),
    reply_to=(),
    date=datetime.datetime(2004, 11, 7, 18, 23, 56, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=75600))),
    date_str='Sun, 07 Nov 2004 18:23:56 -0300',
    text="If you're in need of a good RX site for online purchases, we are your answer.\r\n\r\nWith Tens of Thousands of happy customers who saved huge, you can't go wrong.\r\n\r\nhttp://magyar8stator.com/26 Lots More Info Here\r\n\r\nAbove URL is for more info & if you are interested.",
    html='If you\'re in need of a good RX site for online purchases, we are your answer.<br>\r\n<br>\r\nWith Tens of Thousands of happy customers who saved huge, you can\'t go wrong.<br>\r\n<br>\r\n<a href="http://magyar8stator.com/26">Lots More Info Here</a><br>\r\n<br>\r\n<br>\r\nAbove URL is for more info & if you are interested.<br>\r\n\r\n\r\n\r\n',
    headers={'return-path': ('<fyouizjnp@swissonline.ch>',), 'delivered-to': ('em-ca-bait-precedes@em.ca',), 'received': ('(qmail 7622 invoked by uid 115); 7 Nov 2004 21:30:59 -0000', 'from fyouizjnp@swissonline.ch by churchill by uid 64011 with qmail-scanner-1.22 \r\n (clamdscan: 0.75-1. spamassassin: 2.63.  Clear:RC:0(222.47.112.31):. \r\n Processed in 1.163709 secs); 07 Nov 2004 21:30:59 -0000', 'from unknown (HELO 209.5.178.248) (222.47.112.31)\r\n  by churchill.factcomp.com with SMTP; 7 Nov 2004 21:30:57 -0000'), 'message-id': ('<qlrqpxforpx$RND_WORDjyeottngpx@sympatico.ca>',), 'from': ('"Wilmer Capps" <fyouizjnp@swissonline.ch>',), 'to': ('bait-passover@em.ca',), 'subject': ('Low or High Blood Pressure? We can help.',), 'date': ('Sun, 07 Nov 2004 18:23:56 -0300',), 'x-mailer': ('gene annulus',), 'pneumococcus-polyhedral': ('belgrade hanoverian lima',), 'mime-version': ('1.0',), 'content-type': ('multipart/alternative;\r\n           boundary="----=_NextPart_000_003A_5008K66J.3Z4LC80J"',)},
    attachments=[],
    from_values=EmailAddress(name='Wilmer Capps', email='fyouizjnp@swissonline.ch'),
    to_values=(EmailAddress(name='', email='bait-passover@em.ca'),),
    cc_values=(),
    bcc_values=(),
    reply_to_values=(),
)